tinyMCE.addI18n('tw.simple',{"cleanup_desc":"\u6e05\u9664\u683c\u5f0f","redo_desc":"\u53d6\u6d88\u5fa9\u539f (Ctrl+Y)","undo_desc":"\u5fa9\u539f (Ctrl+Z)","numlist_desc":"\u7de8\u865f\u5217\u8868","bullist_desc":"\u9805\u76ee\u5217\u8868","striketrough_desc":"\u522a\u9664\u7dda","underline_desc":"\u5e95\u7dda (Ctrl+U)","italic_desc":"\u659c\u9ad4 (Ctrl+I)","bold_desc":"\u7c97\u9ad4(Ctrl+B)"});