tinyMCE.addI18n('tt.simple',{"cleanup_desc":"\u6e05\u9664\u5167\u5bb9","redo_desc":"\u91cd\u4f5c\u8b8a\u66f4 (Ctrl+Y)","undo_desc":"\u53d6\u6d88\u8b8a\u66f4 (Ctrl+Z)","numlist_desc":"\u7de8\u865f","bullist_desc":"\u6e05\u55ae\u7b26\u865f","striketrough_desc":"\u4e2d\u5283\u7dda","underline_desc":"\u5e95\u7dda (Ctrl+U)","italic_desc":"\u659c\u9ad4(Ctrl+I)","bold_desc":"\u7c97\u9ad4(Ctrl+B)"});