tinyMCE.addI18n('ta.advhr_dlg',{size:"\u0b89\u0baf\u0bb0\u0bae\u0bcd",noshade:"\u0ba8\u0bbf\u0bb4\u0bb2\u0bcd \u0b87\u0bb2\u0bcd\u0bb2\u0bc8",width:"\u0b85\u0b95\u0bb2\u0bae\u0bcd",normal:"Normal",widthunits:"Units"});