tinyMCE.addI18n('lb.template_dlg',{title:"Virlagen",label:"Virlag","desc_label":"Beschreiwung",desc:"Virgef\u00e4erdegte Virlageninhalt af\u00fcgen",select:"Virlag auswielen",preview:"Virschau",warning:"Warnung: Eng Virlag mat enger anerer ze aktualis\u00e9iere kann zu Dateverloscht f\u00e9ieren!","mdate_format":"%Y-%m-%d %H:%M:%S","cdate_format":"%Y-%m-%d %H:%M:%S","months_long":"Januar,Februar,M\u00e4erz,Abr\u00ebll,Mee,Juni,Juli,August,September,Oktober,November,Dezember","months_short":"Jan,Feb,M\u00e4erz,Abr,Mee,Juni,Juli,Aug,Sept,Okt,Nov,Dez","day_long":"Sonndeg,M\u00e9indeg,D\u00ebnschdeg,M\u00ebttwoch,Donneschdeg,Freides,Samschdeg,Sonndeg","day_short":"So,M\u00e9,D\u00eb,M\u00eb,Do,Fr,Sa,So"});