tinyMCE.addI18n('lb.paste_dlg',{"word_title":"Dr\u00e9ckt op \u00c4rer Tastatur Ctrl+V, um den Text an ze f\u00fcgen.","text_linebreaks":"Zeilen\u00ebmbr\u00ebch b\u00e4ibehalen","text_title":"Dr\u00e9ckt op \u00c4rer Tastatur Ctrl+V, fir den Text an ze f\u00fcgen."});