tinyMCE.addI18n('ta.emotions_dlg',{cry:"\u0b85\u0bb4\u0bc1\u0ba4\u0bb2\u0bcd",cool:"\u0b85\u0bae\u0bc8\u0ba4\u0bbf\u0baf\u0bbe\u0ba9",desc:"\u0b89\u0ba3\u0bb0\u0bcd\u0bb5\u0bc1\u0b95\u0bb3\u0bcd",title:"\u0b89\u0ba3\u0bb0\u0bcd\u0b9a\u0bcd\u0b9a\u0bbf\u0baf\u0bc8 \u0b9a\u0bca\u0bb0\u0bc1\u0b95\u0bc1\u0b95",yell:"\u0b95\u0ba4\u0bcd\u0ba4\u0bb2\u0bcd",wink:"\u0b87\u0bae\u0bc8 \u0b95\u0bc6\u0bbe\u0b9f\u0bcd\u0b9f\u0bc1",undecided:"\u0bae\u0bc1\u0b9f\u0bbf\u0bb5\u0bc1\u0b9a\u0bc6\u0baf\u0bcd\u0baf\u0baa\u0bcd\u0baa\u0b9f\u0bbe\u0ba4\u0ba4\u0bc1","tongue_out":"\u0ba8\u0bbe\u0b95\u0bcd\u0b95\u0bc1 \u0ba8\u0bc0\u0b9f\u0bcd\u0b9f\u0bb2\u0bcd",surprised:"\u0b86\u0b9a\u0bcd\u0b9a\u0bb0\u0bbf\u0baf\u0bae\u0bbe\u0b95",smile:"\u0baa\u0bc1\u0ba9\u0bcd\u0ba9\u0b95\u0bc8",sealed:"Sealed","money_mouth":"Money mouth",laughing:"\u0b9a\u0bbf\u0bb0\u0bbf\u0ba4\u0bcd\u0ba4\u0bb2\u0bcd",kiss:"\u0bae\u0bc1\u0ba4\u0bcd\u0ba4\u0bae\u0bcd",innocent:"Innocent",frown:"\u0bae\u0bc1\u0b95\u0b9a\u0bcd\u0b9a\u0bc1\u0bb3\u0bbf\u0baa\u0bcd\u0baa\u0bc1","foot_in_mouth":"Foot in mouth",embarassed:"\u0ba4\u0bb0\u0bcd\u0bae\u0b9a\u0b99\u0bcd\u0b95\u0b9f\u0ba4\u0bcd\u0ba4\u0bbf\u0bb2\u0bcd",usage:"Use left and right arrows to navigate."});