tinyMCE.addI18n('sy.advanced',{"underline_desc":"\u072c\u071a\u0718\u072c \u0713\u0330\u072a\u0713\u0710 (Ctrl U)","italic_desc":"\u0713\u0722\u071d\u0710 (Ctrl l)","bold_desc":"\u071a\u0720\u071d\u0721\u0710 (Ctrl B)",dd:"\u0721\u0715\u0725\u072c\u0710 \u0715\u0710\u071d\u0722\u071d\u0718\u072c\u0710",dt:"\u071a\u072b\u072c\u0710 \u0715\u0721\u0715\u0725\u072c\u0710",samp:"\u071b\u0718\u0726\u032e\u0723\u0710 \u0715\u071f\u0718\u0715",code:"\u071f\u0718\u0715",blockquote:"\u0721\u072b\u0720\u071d \u0720\u0722\u0723\u0712\u0742\u072c\u0710",h6:"\u072a\u072b\u0718\u072c\u0710 6",h5:"\u072a\u072b\u0718\u072c\u0710 5",h4:"\u072a\u072b\u0718\u072c\u0710 4",h3:"\u072a\u072b\u0718\u072c\u0710 3",h2:"\u072a\u072b\u0718\u072c\u0710 2",h1:"\u072a\u072b\u0718\u072c\u0710 1",pre:"\u0721\u0718\u072a\u071d\u0719\u0710 \u0720\u0729\u0715\u0747\u0721\u0710",address:"\u0721\u0718\u0722\u0725\u0710",div:"\u0726\u0720\u071d\u0713\u073c\u0718\u072c\u0710",paragraph:"\u0726\u072c\u0713\u073c\u0721\u0710",block:"\u0710\u0723\u071f\u071d\u0721\u0710",fontdefault:"\u0723\u072a\u071b\u0710 \u0715\u0712\u071d\u072c\u0718\u072c\u0710","font_size":"\u0721\u072b\u0718\u071a\u072c\u0710 \u0715\u0723\u072a\u071b\u0710","style_select":"\u0710\u0723\u071f\u071d\u0721\u0308\u0710","anchor_delta_height":"","anchor_delta_width":"","charmap_delta_height":"","charmap_delta_width":"","colorpicker_delta_height":"","colorpicker_delta_width":"","link_delta_height":"","link_delta_width":"","image_delta_height":"","image_delta_width":"","more_colors":"More Colors...","toolbar_focus":"Jump to tool buttons - Alt+Q, Jump to editor - Alt-Z, Jump to element path - Alt-X",newdocument:"Are you sure you want clear all contents?",path:"Path","clipboard_msg":"Copy/Cut/Paste is not available in Mozilla and Firefox.\nDo you want more information about this issue?","blockquote_desc":"Block Quote","help_desc":"Help","newdocument_desc":"New Document","image_props_desc":"Image Properties","paste_desc":"Paste (Ctrl+V)","copy_desc":"Copy (Ctrl+C)","cut_desc":"Cut (Ctrl+X)","anchor_desc":"Insert/Edit Anchor","visualaid_desc":"show/Hide Guidelines/Invisible Elements","charmap_desc":"Insert Special Character","backcolor_desc":"Select Background Color","forecolor_desc":"Select Text Color","custom1_desc":"Your Custom Description Here","removeformat_desc":"Remove Formatting","hr_desc":"Insert Horizontal Line","sup_desc":"Superscript","sub_desc":"Subscript","code_desc":"Edit HTML Source","cleanup_desc":"Cleanup Messy Code","image_desc":"Insert/Edit Image","unlink_desc":"Unlink","link_desc":"Insert/Edit Link","redo_desc":"Redo (Ctrl+Y)","undo_desc":"Undo (Ctrl+Z)","indent_desc":"Increase Indent","outdent_desc":"Decrease Indent","numlist_desc":"Insert/Remove Numbered List","bullist_desc":"Insert/Remove Bulleted List","justifyfull_desc":"Align Full","justifyright_desc":"Align Right","justifycenter_desc":"Align Center","justifyleft_desc":"Align Left","striketrough_desc":"Strikethrough","help_shortcut":"Press ALT-F10 for toolbar. Press ALT-0 for help","rich_text_area":"Rich Text Area","shortcuts_desc":"Accessability Help",toolbar:"Toolbar"});