tinyMCE.addI18n('lb.fullpage_dlg',{title:"Dokument-Eegeschaften","meta_tab":"Allgemeng","appearance_tab":"Ausgesinn","advanced_tab":"Erweidert","meta_props":"Meta-Informatioun",langprops:"Sprooch a Kod\u00e9ierung","meta_title":"Titel","meta_keywords":"Sch\u00ebsselwierder","meta_description":"Beschreiwung","meta_robots":"Roboter",doctypes:"DocType",langcode:"Sproochcode",langdir:"Spoochrichtung",ltr:"L\u00e9nks no Riets",rtl:"Riets no L\u00e9nks","xml_pi":"XML Deklaratioun",encoding:"Zeechekod\u00e9ierung","appearance_bgprops":"Hannergrond-Eegeschaften","appearance_marginprops":"Ofst\u00e4nn vum Body","appearance_linkprops":"Linkfuerwen","appearance_textprops":"Text-Eegeschaften",bgcolor:"Hannergrondfuerf",bgimage:"Hannergrondbild","left_margin":"L\u00e9nken Ofstand","right_margin":"Rietsen Ofstand","top_margin":"Ieweschten Ofstand","bottom_margin":"\u00cbnneschten Ofstand","text_color":"Textfuerf","font_size":"Schr\u00ebftgr\u00e9isst","font_face":"Schr\u00ebftaart","link_color":"Linkfuerf","hover_color":"Hover-Fuerf","visited_color":"Besicht-Fuerf","active_color":"Aktiv-Fuerf",textcolor:"Fuerf",fontsize:"Schr\u00ebftgr\u00e9ist",fontface:"Schr\u00ebftaart","meta_index_follow":"Indiz\u00e9ieren, an de Linken nogoen","meta_index_nofollow":"Indiz\u00e9ieren, m\u00e4 de Linken net nogoen","meta_noindex_follow":"Net indiz\u00e9ieren, m\u00e4 de Linken nogoen","meta_noindex_nofollow":"Net indiz\u00e9ieren an och net de Linken nogoen","appearance_style":"CSS-Stil Blat a Stileegeschaften",stylesheet:"CSS-Stil Blat",style:"CSS-Stil",author:"Auteur",copyright:"Copyright",add:"Neit Element b\u00e4if\u00fcgen",remove:"Ausgewielt Element ewechhuelen",moveup:"Ausgewielt Element nach uewen beweegen",movedown:"Ausgewielt Element no \u00ebnnen beweegen","head_elements":"Iwwerschr\u00ebftenelementer",info:"Informatioun","add_title":"Titel-Element","add_meta":"Meta-Element","add_script":"Script-Element","add_style":"Stil-Element","add_link":"Link-Element","add_base":"Basis-Element","add_comment":"HTML-Kommentar","title_element":"Titel-Element","script_element":"Script-Element","style_element":"Stil-Element","base_element":"Basis-Element","link_element":"Link-Element","meta_element":"Meta_Element","comment_element":"Kommentar",src:"Src",language:"Sprooche",href:"Href",target:"Zil",type:"Typ",charset:"Zeechesaz",defer:"Defer",media:"Media",properties:"Eegeschaften",name:"Numm",value:"W\u00e4ert",content:"Inhalt",rel:"Rel",rev:"Rev",hreflang:"Href lang","general_props":"Allgemeng","advanced_props":"Erweidert"});