tinyMCE.addI18n('lb.advanced',{"underline_desc":"\u00cbnnerstrach (Strg+U)","italic_desc":"Kursiv (Strg+I)","bold_desc":"Fett (Strg+B)",dd:"Definitiounsbeschreiwung",dt:"Definitiounsbegr\u00ebff",samp:"Beispill",code:"Code",blockquote:"Zitatblock",h6:"Iwwerschr\u00ebft 6",h5:"Iwwerschr\u00ebft 5",h4:"Iwwerschr\u00ebft 4",h3:"Iwwerschr\u00ebft 3",h2:"Iwwerschr\u00ebft 2",h1:"Iwwerschr\u00ebft 1",pre:"R\u00e9idaten",address:"Adress",div:"Zesummenh\u00e4nkende Ber\u00e4ich",paragraph:"Ofsatz",block:"Virlag",fontdefault:"Schr\u00ebftaart","font_size":"Schr\u00ebftgr\u00e9isst","style_select":"Format","anchor_delta_width":"13","more_colors":"Weider Fuerwen","toolbar_focus":"Bei d\'Geschirleescht sprangen: Alt+Q; Bei den Editor sprangen: Alt+Z; Bei den Elementpad sprangen: Alt+X",newdocument:"W\u00ebllt Dir wierklech de ganzen Inhalt l\u00e4schen?",path:"Pad","clipboard_msg":"Kop\u00e9ieren, Ausschneiden an Af\u00fcgen sinn am Mozilla Firefox net m\u00e9iglech.\nW\u00ebllt Dir m\u00e9i iwwert d\u00ebse Problem gewuer ginn?","blockquote_desc":"Zitatblock","help_desc":"H\u00ebllef","newdocument_desc":"Neit Dokument","image_props_desc":"Bildeegeschaften","paste_desc":"Af\u00fcgen","copy_desc":"Kop\u00e9ieren","cut_desc":"Ausschneiden","anchor_desc":"Anker af\u00fcgen/ver\u00e4nneren","visualaid_desc":"H\u00ebllefslinnen an onsiichtbar Elementer an-/ausblennen","charmap_desc":"Sonnerzeechen af\u00fcgen","backcolor_desc":"Hannergrondfuerf","forecolor_desc":"Textfuerf","custom1_desc":"Benotzerdefin\u00e9iert Beschreiwung","removeformat_desc":"Format\u00e9ierungen zer\u00e9cksetzen","hr_desc":"Trennlinn af\u00fcgen","sup_desc":"H\u00e9ichgestallt","sub_desc":"D\u00e9ifgestallt","code_desc":"HTML-Quellcode beaarbechten","cleanup_desc":"Quellcode botzen","image_desc":"Bild af\u00fcgen/ver\u00e4nneren","unlink_desc":"Link ewechhuelen","link_desc":"Link af\u00fcgen/ver\u00e4nneren","redo_desc":"Widderhuelen (Strg+Y)","undo_desc":"R\u00e9ckg\u00e4ngeg (Strg+Z)","indent_desc":"Ar\u00e9cken","outdent_desc":"Ausr\u00e9cken","numlist_desc":"Sort\u00e9iert L\u00ebscht","bullist_desc":"Onsort\u00e9iert L\u00ebscht","justifyfull_desc":"B\u00e9ids\u00e4iteg align\u00e9iert","justifyright_desc":"Riets align\u00e9iert","justifycenter_desc":"Zentr\u00e9iert","justifyleft_desc":"L\u00e9nks align\u00e9iert","striketrough_desc":"Duerchgestrach","anchor_delta_height":"","charmap_delta_height":"","charmap_delta_width":"","colorpicker_delta_height":"","colorpicker_delta_width":"","link_delta_height":"","link_delta_width":"","image_delta_height":"","image_delta_width":"","help_shortcut":"Press ALT-F10 for toolbar. Press ALT-0 for help","rich_text_area":"Rich Text Area","shortcuts_desc":"Accessability Help",toolbar:"Toolbar"});