tinyMCE.addI18n('ia.fullpage_dlg',{title:"\u6863\u6848\u5c5e\u6027","meta_tab":"\u57fa\u672c","appearance_tab":"\u5916\u89c2","advanced_tab":"\u9ad8\u7ea7","meta_props":"\u4e2d\u7ee7\u6570\u636e\u5377\u6807\u5c5e\u6027",langprops:"\u8bed\u8a00","meta_title":"\u6807\u9898","meta_keywords":"\u5173\u952e\u8bcd","meta_description":"\u5185\u5bb9\u8bf4\u660e","meta_robots":"\u673a\u5668\u4eba",doctypes:"DocType",langcode:"\u8bed\u8a00\u7f16\u7801",langdir:"\u8bed\u8a00\u4e66\u5199\u65b9\u5411",ltr:"\u4ece\u5de6\u5230\u53f3",rtl:"\u4ece\u53f3\u5230\u5de6","xml_pi":"XML \u58f0\u660e",encoding:"\u5b57\u7b26\u7f16\u7801","appearance_bgprops":"\u80cc\u666f\u5c5e\u6027","appearance_marginprops":"\u8fb9\u8ddd","appearance_linkprops":"\u8fde\u7ed3\u989c\u8272","appearance_textprops":"\u6587\u5b57\u5c5e\u6027",bgcolor:"\u80cc\u666f\u989c\u8272",bgimage:"\u80cc\u666f\u56fe\u7247","left_margin":"\u5de6\u8fb9\u8ddd","right_margin":"\u53f3\u8fb9\u8ddd","top_margin":"\u4e0a\u8fb9\u8ddd","bottom_margin":"\u4e0b\u8fb9\u8ddd","text_color":"\u6587\u5b57\u989c\u8272","font_size":"\u6587\u5b57\u5927\u5c0f","font_face":"\u5b57\u4f53","link_color":"\u8fde\u7ed3\u989c\u8272","hover_color":"Hover \u989c\u8272","visited_color":"Visited \u989c\u8272","active_color":"Active \u989c\u8272",textcolor:"\u989c\u8272",fontsize:"\u6587\u5b57\u5927\u5c0f",fontface:"\u5b57\u4f53","meta_index_follow":"Index and follow the links","meta_index_nofollow":"Index and don\'t follow the links","meta_noindex_follow":"Do not index but follow the links","meta_noindex_nofollow":"Do not index and don\\\'t follow the links","appearance_style":"\u6837\u5f0f\u8868\u5c5e\u6027",stylesheet:"\u6837\u5f0f\u8868",style:"\u6837\u5f0f",author:"\u4f5c\u8005",copyright:"\u7248\u6743",add:"\u6dfb\u52a0\u65b0\u5bf9\u8c61",remove:"\u5220\u9664\u9009\u62e9\u7684\u5bf9\u8c61",moveup:"\u5411\u4e0a\u79fb\u52a8\u9009\u62e9\u7684\u5bf9\u8c61",movedown:"\u5411\u4e0b\u79fb\u52a8\u9009\u62e9\u7684\u5bf9\u8c61","head_elements":"\u5934\u5bf9\u8c61",info:"\u4fe1\u606f","add_title":"\u67e5\u627e\u5bf9\u8c61","add_meta":"\u5143\u5bf9\u8c61","add_script":"\u811a\u672c\u5bf9\u8c61","add_style":"\u6837\u5f0f\u5bf9\u8c61","add_link":"\u8fde\u7ed3\u5316\u5bf9\u8c61","add_base":"Base\u5bf9\u8c61","add_comment":"\u6ce8\u91ca\u5bf9\u8c61","title_element":"\u67e5\u627e\u5bf9\u8c61","script_element":"\u811a\u672c\u5bf9\u8c61","style_element":"\u6837\u5f0f\u5bf9\u8c61","base_element":"Base\u5bf9\u8c61","link_element":"\u8fde\u7ed3\u5316\u5bf9\u8c61","meta_element":"\u5143\u5bf9\u8c61","comment_element":"\u6ce8\u91ca\u5bf9\u8c61",src:"Src",language:"\u8bed\u8a00",href:"Href",target:"\u76ee\u6807",type:"\u7c7b\u578b",charset:"\u5b57\u7b26\u96c6",defer:"Defer",media:"\u5a92\u4f53",properties:"\u5c5e\u6027",name:"\u540d",value:"\u503c",content:"\u5185\u5bb9",rel:"Rel",rev:"Rev",hreflang:"Href lang","general_props":"\u57fa\u672c","advanced_props":"\u9ad8\u7ea7"});