tinyMCE.addI18n('tt.xhtmlxtras_dlg',{"attribs_title":"\u63d2\u5165/\u7de8\u8f2f \u5c6c\u6027","option_rtl":"\u5f9e\u53f3\u5230\u5de6","option_ltr":"\u5f9e\u5de6\u5230\u53f3","insert_date":"\u63d2\u5165\u7576\u524d\u65e5\u671f/\u6642\u9593",remove:"\u79fb\u9664","title_cite_element":"\u5f15\u7528\u7269\u4ef6","title_abbr_element":"\u7e2e\u5beb\u7269\u4ef6","title_acronym_element":"\u9996\u5b57\u6bcd\u7e2e\u5beb\u7269\u4ef6","title_del_element":"\u522a\u9664\u7269\u4ef6","title_ins_element":"\u63d2\u5165\u7269\u4ef6","fieldset_events_tab":"\u7269\u4ef6\u4e8b\u4ef6","fieldset_attrib_tab":"\u7269\u4ef6\u5c6c\u6027","fieldset_general_tab":"\u57fa\u672c","events_tab":"\u4e8b\u4ef6","attrib_tab":"\u5c6c\u6027","general_tab":"\u57fa\u672c","attribute_attrib_tab":"\u5c6c\u6027","attribute_events_tab":"\u4e8b\u4ef6","attribute_label_accesskey":"\u5feb\u901f\u9375","attribute_label_tabindex":"Tab\u7d22\u5f15","attribute_label_langcode":"\u8a9e\u8a00","attribute_option_rtl":"\u5f9e\u53f3\u5230\u5de6","attribute_option_ltr":"\u5f9e\u5de6\u5230\u53f3","attribute_label_langdir":"\u6587\u5b57\u66f8\u5beb\u65b9\u5411","attribute_label_datetime":"\u65e5\u671f/\u6642\u9593","attribute_label_cite":"\u5f15\u7528","attribute_label_style":"\u6a23\u5f0f","attribute_label_class":"\u6a23\u5f0f\u985e","attribute_label_id":"ID","attribute_label_title":"\u641c\u5c0b"});