tinyMCE.addI18n('lb.simple',{"cleanup_desc":"Quellcode botzen","redo_desc":"Widderhuelen (Strg+Y)","undo_desc":"R\u00e9ckg\u00e4ngeg (Strg+Z)","numlist_desc":"Sort\u00e9iert L\u00ebscht","bullist_desc":"Onsort\u00e9iert L\u00ebscht","striketrough_desc":"Duerchgestrach","underline_desc":"\u00cbnnerstrach (Strg+U)","italic_desc":"Kursiv (Strg+I)","bold_desc":"Fett (Strg+B)"});