tinyMCE.addI18n('cn.simple',{"cleanup_desc":"\u6e05\u7406\u4ee3\u7801","redo_desc":"\u91cd\u505a (Ctrl Y)","undo_desc":"\u64a4\u9500 (Ctrl Z)","numlist_desc":"\u6709\u5e8f\u7f16\u53f7","bullist_desc":"\u65e0\u5e8f\u7f16\u53f7","striketrough_desc":"\u5220\u9664\u7ebf","underline_desc":"\u4e0b\u5212\u7ebf (Ctrl U)","italic_desc":"\u659c\u4f53 (Ctrl I)","bold_desc":"\u7c97\u4f53 (Ctrl B)"});