tinyMCE.addI18n('ml.advanced',{"underline_desc":"Underline (Ctrl+U)","italic_desc":"Italic (Ctrl+I)","bold_desc":"Bold (Ctrl+B)",dd:"Definition description",dt:"Definition term ",samp:"Code sample",code:"Code",blockquote:"Blockquote",h6:"\u0d24\u0d32\u0d15\u0d4d\u0d15\u0d46\u0d1f\u0d4d\u0d1f\u0d41\u0d4d  6",h5:"\u0d24\u0d32\u0d15\u0d4d\u0d15\u0d46\u0d1f\u0d4d\u0d1f\u0d41\u0d4d  5",h4:"\u0d24\u0d32\u0d15\u0d4d\u0d15\u0d46\u0d1f\u0d4d\u0d1f\u0d41\u0d4d  4",h3:"\u0d24\u0d32\u0d15\u0d4d\u0d15\u0d46\u0d1f\u0d4d\u0d1f\u0d41\u0d4d  3",h2:"\u0d24\u0d32\u0d15\u0d4d\u0d15\u0d46\u0d1f\u0d4d\u0d1f\u0d41\u0d4d  2",h1:"\u0d24\u0d32\u0d15\u0d4d\u0d15\u0d46\u0d1f\u0d4d\u0d1f\u0d41\u0d4d 1",pre:"Preformatted",address:"\u0d35\u0d3f\u0d32\u0d3e\u0d38\u0d02",div:"Div",paragraph:"\u0d16\u0d23\u0d4d\u0d21\u0d3f\u0d15",block:"\u0d18\u0d1f\u0d28",fontdefault:"\u0d05\u0d15\u0d4d\u0d37\u0d30\u0d15\u0d42\u0d1f\u0d4d\u0d1f\u0d02","font_size":"\u0d05\u0d15\u0d4d\u0d37\u0d30\u0d35\u0d32\u0d41\u0d2a\u0d4d\u0d2a\u0d02","style_select":"\u0d30\u0d42\u0d2a\u0d2d\u0d02\u0d17\u0d3f","more_colors":"More colors","toolbar_focus":"Jump to tool buttons - Alt+Q, Jump to editor - Alt-Z, Jump to element path - Alt-X",newdocument:"Are you sure you want clear all contents?",path:"Path","clipboard_msg":"\u0d2e\u0d41\u0d31\u0d3f\u0d15\u0d4d\u0d15\u0d32\u0d4d\u200d/\u0d2a\u0d15\u0d30\u0d4d\u200d\u0d24\u0d4d\u0d24\u0d32\u0d4d\u200d/\u0d12\u0d1f\u0d4d\u0d1f\u0d3f\u0d15\u0d4d\u0d15\u0d32\u0d4d\u200d  \u0d0e\u0d28\u0d4d\u0d28\u0d3f\u0d35 \'\u0d2e\u0d4b\u0d38\u0d3f\u0d32\u0d4d\u0d32\'\u0d2f\u0d3f\u0d32\u0d41\u0d02 \'\u0d2b\u0d2f\u0d30\u0d4d\u200d\u0d2b\u0d4b\u0d15\u0d4d\u0d38\u0d4d\'\u0d32\u0d41\u0d02 \u0d32\u0d2d\u0d4d\u0d2f\u0d2e\u0d32\u0d4d\u0d32. \n\u0d24\u0d3e\u0d19\u0d4d\u0d15\u0d33\u0d4d\u200d\u0d15\u0d4d\u0d15\u0d41 \u0d07\u0d24\u0d3f\u0d28\u0d46 \u0d15\u0d41\u0d31\u0d3f\u0d1a\u0d4d\u0d1a\u0d41\u0d4d \u0d15\u0d42\u0d1f\u0d41\u0d24\u0d32\u0d4d\u200d \u0d05\u0d31\u0d3f\u0d2f\u0d23\u0d4b ?","blockquote_desc":"Blockquote","help_desc":"Help","newdocument_desc":"New document","image_props_desc":"Image properties","paste_desc":"\u0d12\u0d1f\u0d4d\u0d1f\u0d3f\u0d15\u0d4d\u0d15\u0d41\u0d15","copy_desc":"\u0d2a\u0d15\u0d30\u0d4d\u200d\u0d24\u0d4d\u0d24\u0d41\u0d15","cut_desc":"\u0d2e\u0d41\u0d31\u0d3f\u0d15\u0d4d\u0d15\u0d41\u0d15","anchor_desc":"Insert/edit anchor","visualaid_desc":"Toggle guidelines/invisible elements","charmap_desc":"Insert custom character","backcolor_desc":"Select background color","forecolor_desc":"Select text color","custom1_desc":"Your custom description here","removeformat_desc":"Remove formatting","hr_desc":"Insert horizontal ruler","sup_desc":"Superscript","sub_desc":"Subscript","code_desc":"Edit HTML Source","cleanup_desc":"Cleanup messy code","image_desc":"Insert/edit image","unlink_desc":"\u0d35\u0d3f\u0d1a\u0d4d\u0d1b\u0d47\u0d26\u0d3f\u0d15\u0d4d\u0d15\u0d41\u0d15","link_desc":"Insert/edit link","redo_desc":"Redo (Ctrl+Y)","undo_desc":"Undo (Ctrl+Z)","indent_desc":"Indent","outdent_desc":"Outdent","numlist_desc":"Ordered list","bullist_desc":"Unordered list","justifyfull_desc":"Align full","justifyright_desc":"Align right","justifycenter_desc":"Align center","justifyleft_desc":"Align left","striketrough_desc":"Strikethrough","anchor_delta_height":"","anchor_delta_width":"","charmap_delta_height":"","charmap_delta_width":"","colorpicker_delta_height":"","colorpicker_delta_width":"","link_delta_height":"","link_delta_width":"","image_delta_height":"","image_delta_width":"","help_shortcut":"Press ALT-F10 for toolbar. Press ALT-0 for help","rich_text_area":"Rich Text Area","shortcuts_desc":"Accessability Help",toolbar:"Toolbar"});