<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">
<html>
<head>
    <title>{{ flatpage.title }}</title>
</head>
<body>

<h1>{{ flatpage.title }}</h1>

{{ flatpage.content }}

</body>
</html>
