tinyMCE.addI18n('tn.simple',{"cleanup_desc":"Kolomaka khoudi e meragaraga ","redo_desc":"Dira-gape (Ctrl+Y)","undo_desc":"Dirolola(Ctrl+Z)","numlist_desc":"Tatelano e rulagantsweng","bullist_desc":"Tatelano e thakathakaneng","striketrough_desc":"Sega-bogare","underline_desc":"Sega-tselana (Ctrl+U)","italic_desc":"Tseketa (Ctrl+I)","bold_desc":"Bokima (Ctrl+B)"});