tinyMCE.addI18n('lb.advanced_dlg',{"link_list":"Linkl\u00ebscht","link_is_external":"D\u00ebs Adress sch\u00e9ngt een externen Link ze sinn. W\u00ebll Dir den dofir ben\u00e9idegt http:// virdru stellen?","link_is_email":"D\u00ebs Adress sch\u00e9ngt eng Email-Adress ze sinn. W\u00ebll Dir den dofir ben\u00e9idegt mailto: virdru stellen?","link_titlefield":"Titel","link_target_blank":"Nei F\u00ebnster opmaachen","link_target_same":"An der selwechter F\u00ebnster opmaachen","link_target":"F\u00ebnster","link_url":"Adress","link_title":"Link af\u00fcgen/beaarbechten","image_align_right":"Riets","image_align_left":"L\u00e9nks","image_align_textbottom":"\u00cbnnen am Text","image_align_texttop":"Uewen am Text","image_align_bottom":"\u00cbnnen","image_align_middle":"M\u00ebtteg","image_align_top":"Uewen","image_align_baseline":"Zeil","image_align":"Ausriichtung","image_hspace":"Horizontalen Ofstand","image_vspace":"Vertikalen Ofstand","image_dimensions":"Ausmoossen","image_alt":"Alternativtext","image_list":"Billerleescht","image_border":"Rumm","image_src":"Adress","image_title":"Bild af\u00fcgen/beaarbechten","charmap_title":"Sonnerzeechen","colorpicker_name":"Numm:","colorpicker_color":"Fuerf:","colorpicker_named_title":"Benannte Fuerwen","colorpicker_named_tab":"Benannte Fuerwen","colorpicker_palette_title":"Fuerfpalette","colorpicker_palette_tab":"Palette","colorpicker_picker_title":"Fuerfselectioun","colorpicker_picker_tab":"Fuerfselectioun","colorpicker_title":"Fuerf","code_wordwrap":"Automateschen Zeilen\u00ebmbroch","code_title":"HTML-Quellcode beaarbechten","anchor_name":"Numm vum Anker","anchor_title":"Anker af\u00fcgen/ver\u00e4nneren","about_loaded":"Geluede Pluginen","about_version":"Versioun","about_author":"Auteur","about_plugin":"Plugin","about_plugins":"Pluginen","about_license":"Lizenzbedingungen","about_help":"H\u00ebllef","about_general":"Iwwer\u2026","about_title":"Iwwer TinyMCE","anchor_invalid":"Please specify a valid anchor name.","accessibility_help":"Accessibility Help","accessibility_usage_title":"General Usage"});