tinyMCE.addI18n('tn.advanced_dlg',{"link_list":"Link list","link_is_external":"The URL you entered seems to external link, do you want to add the required http:// prefix?","link_is_email":"The URL you entered seems to be an email address, do you want to add the required mailto: prefix?","link_titlefield":"Title","link_target_blank":"Open link in a new window","link_target_same":"Open link in the same window","link_target":"Target","link_url":"Link URL","link_title":"Insert/edit link","image_align_right":"Right","image_align_left":"Left","image_align_textbottom":"Text bottom","image_align_texttop":"Text top","image_align_bottom":"Bottom","image_align_middle":"Middle","image_align_top":"Top","image_align_baseline":"Baseline","image_align":"Alignment","image_hspace":"Horizontal space","image_vspace":"phatlha e Thamaletseng","image_dimensions":"Dimensions","image_alt":"Kaedi ya setswantsho","image_list":"Tatelano ya setswantsho","image_border":"Molelwane","image_src":"URL ya setswantsho","image_title":"Tsenay/ Baakanya setswantsho","charmap_title":"Tsenya boitirelo jwa khareketa","colorpicker_name":"Leina:","colorpicker_color":"Mmala","colorpicker_named_title":"Mebala e Teilweng","colorpicker_named_tab":"Teilweng","colorpicker_palette_title":"Mebala wa Palette","colorpicker_palette_tab":"Palette","colorpicker_picker_title":"Sethophi sa Mmala","colorpicker_picker_tab":"Sethophi","colorpicker_title":"Thopha mmala","code_wordwrap":"Phuthela lefoko","code_title":"Sebaakanyi sa HTML Source","anchor_name":"Leina la Anchor","anchor_title":"Tsenya/Baakanya anchor","about_loaded":"Dipolaka tse di pegilweng","about_version":"kgatiso","about_author":"Mokwadi","about_plugin":"Polaka","about_plugins":"Dipolaka","about_license":"setankana","about_help":"Thuso","about_general":"kaga","about_title":"kaga TinyMCE","anchor_invalid":"Please specify a valid anchor name.","accessibility_help":"Accessibility Help","accessibility_usage_title":"General Usage"});