tinyMCE.addI18n('ch.simple',{"cleanup_desc":"\u6e05\u9664\u683c\u5f0f","redo_desc":"\u53d6\u6d88\u6062\u590d \uff08Ctrl+Y\uff09","undo_desc":"\u6062\u590d \uff08Ctrl+Z\uff09","numlist_desc":"\u7f16\u53f7\u5217\u8868","bullist_desc":"\u9879\u76ee\u5217\u8868","striketrough_desc":"\u5220\u9664\u7ebf","underline_desc":"\u5e95\u7ebf \uff08Ctrl+U\uff09","italic_desc":"\u659c\u4f53 \uff08Ctrl+I\uff09","bold_desc":"\u7c97\u4f53\uff08Ctrl+B\uff09"});