tinyMCE.addI18n('lb.advlink_dlg',{"target_name":"Numm vun der Zils\u00e4it",classes:"Klassen",style:"Format",id:"ID","popup_position":"Positioun (X/Y)",langdir:"Schr\u00ebftrichtung","popup_size":"Gr\u00e9isst","popup_dependent":"Vun der Elteref\u00ebnster onofh\u00e4ngeg <br /> (n\u00ebmmen Mozilla/Firefox) ","popup_resizable":"Vergr\u00e9isseren vun der F\u00ebnster zouloossen","popup_location":"Adressleescht uweisen","popup_menubar":"Browsermen\u00fc uweisen","popup_toolbar":"Geschirleeschten uweisen","popup_statusbar":"Statusleeschten uweisen","popup_scrollbars":"Scrollbalken uweisen","popup_return":"Link trotz Popup suiv\u00e9ieren","popup_name":"Numm vun der F\u00ebnster","popup_url":"Popup-Adress",popup:"JavaScript-Popup","target_blank":"An enger neier F\u00ebnster opmaachen","target_top":"Am ieweschte Frame opmaacheen (sprengt d\'Frameset)","target_parent":"An der iwwergeuerdneter F\u00ebnster/Frame opmaachen","target_same":"An der selwechter F\u00ebnster/Frame opmaachen","anchor_names":"Anker","popup_opts":"Optiounen","advanced_props":"Erweidert Eegeschaften","event_props":"Evenement","popup_props":"Popup-Eegeschaften","general_props":"Allgemeng Eegeschaften","advanced_tab":"Erweidert","events_tab":"Evenement","popup_tab":"Popup","general_tab":"Allgemeng",list:"Linkl\u00ebscht","is_external":"D\u00ebs Adress sch\u00e9ngt een externe Link ze sinn. W\u00ebllt Dir den dofir ben\u00e9idegte Pr\u00e4fix \"http://\" virdru setzen?","is_email":"D\u00ebs Adress sch\u00e9ngt eng Email-Adress ze sinn. W\u00ebllt Dir den dofir ben\u00e9idegte Pr\u00e4fix \"mailto:\" virdru setzen?",titlefield:"Titel",target:"F\u00ebnster",url:"Adress",title:"Link af\u00fcgen/beaarbechten","link_list":"Linkl\u00ebscht",rtl:"Riets no l\u00e9nks",ltr:"L\u00e9nks no riets",accesskey:"Tastekierzel",tabindex:"Tabindex",rev:"Bez\u00e9iung vum Linkzil zur S\u00e4it",rel:"Bez\u00e9iung vun der S\u00e4it zum Linkzil",mime:"MIME-Typ vun der Zils\u00e4it",encoding:"Zeechekod\u00e9ierung vun der Zils\u00e4it",langcode:"Sproochcode","target_langcode":"Sprooch vun der Zils\u00e4it",width:"Width",height:"Height"});