tinyMCE.addI18n('ta.xhtmlxtras_dlg',{"attribs_title":"Insert/Edit Attributes","option_rtl":"\u0bb5\u0bb2\u0bae\u0bbf\u0bb0\u0bc1\u0ba8\u0bcd\u0ba4\u0bc1 \u0b87\u0b9f\u0bae\u0bcd","option_ltr":"\u0b87\u0b9f\u0bae\u0bbf\u0bb0\u0bc1\u0ba8\u0bcd\u0ba4\u0bc1 \u0bb5\u0bb2\u0bae\u0bcd","insert_date":"Insert current date/time",remove:"Remove","title_cite_element":"Citation Element","title_abbr_element":"Abbreviation Element","title_acronym_element":"Acronym Element","title_del_element":"Deletion Element","title_ins_element":"Insertion Element","fieldset_events_tab":"Element Events","fieldset_attrib_tab":"Element Attributes","fieldset_general_tab":"\u0baa\u0bcb\u0ba4\u0bc1 \u0b85\u0bae\u0bc8\u0baa\u0bcd\u0baa\u0bc1\u0b95\u0bb3\u0bcd","events_tab":"\u0ba8\u0bbf\u0b95\u0bb4\u0bcd\u0bb5\u0bc1\u0b95\u0bb3\u0bcd","attrib_tab":"Attributes","general_tab":"\u0baa\u0bcb\u0ba4\u0bc1","attribute_attrib_tab":"Attributes","attribute_events_tab":"\u0ba8\u0bbf\u0b95\u0bb4\u0bcd\u0bb5\u0bc1\u0b95\u0bb3\u0bcd","attribute_label_accesskey":"AccessKey","attribute_label_tabindex":"TabIndex","attribute_label_langcode":"\u0bae\u0bca\u0bb4\u0bbf","attribute_option_rtl":"\u0bb5\u0bb2\u0bae\u0bbf\u0bb0\u0bc1\u0ba8\u0bcd\u0ba4\u0bc1 \u0b87\u0b9f\u0bae\u0bcd","attribute_option_ltr":"\u0b87\u0b9f\u0bae\u0bbf\u0bb0\u0bc1\u0ba8\u0bcd\u0ba4\u0bc1 \u0bb5\u0bb2\u0bae\u0bcd","attribute_label_langdir":"\u0b89\u0bb0\u0bc8 \u0ba4\u0bbf\u0b9a\u0bc8","attribute_label_datetime":"\u0ba4\u0bc7\u0ba4\u0bbf/\u0ba8\u0bc7\u0bb0\u0bae\u0bcd","attribute_label_cite":"Cite","attribute_label_style":"\u0baa\u0bbe\u0ba3\u0bbf","attribute_label_class":"Class","attribute_label_id":"ID","attribute_label_title":"\u0ba4\u0bb2\u0bc8\u0baa\u0bcd\u0baa\u0bc1"});