tinyMCE.addI18n('ta.advimage_dlg',{"image_list":"\u0baa\u0b9f\u0baa\u0bcd \u0baa\u0b9f\u0bcd\u0b9f\u0bbf\u0baf\u0bb2\u0bcd","align_right":"\u0bb5\u0bb2\u0bae\u0bcd","align_left":"\u0b87\u0b9f\u0bae\u0bcd","align_textbottom":"\u0b89\u0bb0\u0bc8 \u0b95\u0bc0\u0bb4\u0bcd","align_texttop":"\u0b89\u0bb0\u0bc8 \u0bae\u0bc7\u0bb2\u0bcd","align_bottom":"\u0b95\u0bc0\u0bb4\u0bcd","align_middle":"\u0ba8\u0b9f\u0bc1","align_top":"\u0bae\u0bc7\u0bb2\u0bcd","align_baseline":"\u0b85\u0b9f\u0bbf\u0ba4\u0bcd\u0ba4\u0bb3\u0bae\u0bcd",align:"\u0b92\u0bb4\u0bc1\u0b99\u0bcd\u0b95\u0bae\u0bc8\u0baa\u0bcd\u0baa\u0bc1",hspace:"\u0b95\u0bbf\u0b9f\u0bc8\u0bae\u0b9f\u0bcd\u0b9f \u0bb5\u0bc6\u0bb3\u0bbf",vspace:"\u0b9a\u0bc6\u0b99\u0bcd\u0b95\u0bc1\u0ba4\u0bcd\u0ba4\u0bc1 \u0bb5\u0bc6\u0bb3\u0bbf",dimensions:"\u0b85\u0bb3\u0bb5\u0bc1\u0b95\u0bb3\u0bcd",border:"\u0b95\u0bb0\u0bc8",list:"\u0baa\u0b9f\u0baa\u0bcd \u0baa\u0b9f\u0bcd\u0b9f\u0bbf\u0baf\u0bb2\u0bcd",alt:"\u0baa\u0b9f \u0bb5\u0bbf\u0bb5\u0bb0\u0bae\u0bcd",src:"\u0baa\u0b9f \u0b87\u0ba3\u0bc8\u0baf\u0bae\u0bc1\u0b95\u0bb5\u0bb0\u0bbf","dialog_title":"\u0baa\u0b9f\u0ba4\u0bcd\u0ba4\u0bc8\u0b9a\u0bcd \u0b9a\u0bca\u0bb0\u0bc1\u0b95\u0bc1\u0b95/\u0ba4\u0bca\u0b95\u0bc1\u0b95\u0bcd\u0b95","missing_alt":"\u0ba4\u0bbe\u0b99\u0bcd\u0b95\u0bb3\u0bcd \u0baa\u0b9f \u0bb5\u0bbf\u0bb5\u0bb0\u0ba4\u0bcd\u0ba4\u0bc8\u0b9a\u0bcd \u0b9a\u0bc7\u0bb0\u0bcd\u0b95\u0bcd\u0b95\u0bbe\u0bae\u0bb2\u0bcd \u0ba4\u0bca\u0b9f\u0bb0 \u0bb5\u0bbf\u0bb0\u0bc1\u0bae\u0bcd\u0baa\u0bc1\u0b95\u0bbf\u0bb1\u0bc0\u0bb0\u0bcd\u0b95\u0bb3\u0bbe? \u0bb5\u0bbf\u0bb5\u0bb0\u0bae\u0bcd  \u0b87\u0bb2\u0bcd\u0bb2\u0bbe\u0bae\u0bb2\u0bcd, \u0bae\u0bbe\u0bb1\u0bcd\u0bb1\u0bc1\u0ba4\u0bcd\u0ba4\u0bbf\u0bb1\u0ba9\u0bcd \u0b95\u0bca\u0ba3\u0bcd\u0b9f \u0b9a\u0bbf\u0bb2 \u0baa\u0baf\u0ba9\u0bbe\u0bb3\u0bb0\u0bcd\u0b95\u0bb3\u0bcd, \u0b85\u0bb2\u0bcd\u0bb2\u0ba4\u0bc1 \u0b89\u0bb0\u0bc8 \u0bae\u0bc7\u0bb2\u0bcb\u0b9f\u0bbf\u0baf\u0bc8\u0baa\u0bcd \u0baa\u0baf\u0ba9\u0bcd\u0baa\u0b9f\u0bc1\u0ba4\u0bcd\u0ba4\u0bc1\u0baa\u0bb5\u0bb0\u0bcd\u0b95\u0bb3\u0bcd, \u0b85\u0bb2\u0bcd\u0bb2\u0ba4\u0bc1 \u0baa\u0b9f\u0b99\u0bcd\u0b95\u0bb3\u0bcd \u0b95\u0bbe\u0b9f\u0bcd\u0b9f\u0bc1\u0bb5\u0ba4\u0bc8 \u0b87\u0baf\u0bb2\u0bc1\u0bae\u0bc8\u0baa\u0bcd\u0baa\u0b9f\u0bc1\u0ba4\u0bcd\u0ba4\u0bbe\u0bae\u0bb2\u0bcd \u0b87\u0ba3\u0bc8\u0baf\u0ba4\u0bcd\u0ba4\u0bc8 \u0b89\u0bb2\u0bbe\u0bb5\u0bc1\u0baa\u0bb5\u0bb0\u0bcd\u0b95\u0bb3\u0bcd \u0b87\u0bb5\u0bb0\u0bcd\u0b95\u0bb3\u0bbe\u0bb2\u0bcd \u0baa\u0b9f\u0ba4\u0bcd\u0ba4\u0bc8 \u0b85\u0ba3\u0bc1\u0b95 \u0b87\u0baf\u0bb2\u0bbe\u0ba4\u0bc1,","example_img":"\u0bae\u0bc1\u0ba9\u0bcd-\u0ba8\u0bcb\u0b95\u0bcd\u0b95\u0bc1\u0baa\u0bcd \u0baa\u0b9f\u0ba4\u0bcd \u0ba4\u0bcb\u0bb1\u0bcd\u0bb1\u0bae\u0bcd",misc:"\u0ba8\u0bbe\u0ba9\u0bbe\u0bb5\u0bbf\u0ba4",mouseout:"mouse out-\u0b95\u0bcd\u0b95\u0bc1",mouseover:"mouse over-\u0b95\u0bcd\u0b95\u0bc1","alt_image":"\u0bae\u0bbe\u0bb1\u0bcd\u0bb1\u0bc1\u0baa\u0bcd \u0baa\u0b9f\u0bae\u0bcd","swap_image":"\u0b87\u0b9f\u0bae\u0bbe\u0bb1\u0bcd\u0bb1\u0bc1\u0baa\u0bcd \u0baa\u0b9f\u0bae\u0bcd",map:"\u0baa\u0b9f \u0bb5\u0bb0\u0bc8\u0baa\u0b9f\u0bae\u0bcd",id:"Id",rtl:"\u0bb5\u0bb2\u0bae\u0bbf\u0bb0\u0bc1\u0ba8\u0bcd\u0ba4\u0bc1 \u0b87\u0b9f\u0bae\u0bcd",ltr:"\u0b87\u0b9f\u0bae\u0bbf\u0bb0\u0bc1\u0ba8\u0bcd\u0ba4\u0bc1 \u0bb5\u0bb2\u0bae\u0bcd",classes:"Classes",style:"\u0baa\u0bbe\u0ba3\u0bbf","long_desc":"\u0ba8\u0bc0\u0ba3\u0bcd\u0b9f \u0bb5\u0bbf\u0bb5\u0bb0 \u0b87\u0ba3\u0bc8\u0baa\u0bcd\u0baa\u0bc1",langcode:"\u0bae\u0bca\u0bb4\u0bbf\u0b95\u0bcd \u0b95\u0bc1\u0bb1\u0bbf\u0baf\u0bc0\u0b9f\u0bc1",langdir:"\u0bae\u0bca\u0bb4\u0bbf\u0ba4\u0bcd \u0ba4\u0bbf\u0b9a\u0bc8","constrain_proportions":"\u0bb5\u0bbf\u0b95\u0bbf\u0ba4\u0bbe\u0b9a\u0bcd\u0b9a\u0bbe\u0bb0\u0ba4\u0bcd\u0ba4\u0bbf\u0bb2\u0bcd \u0b95\u0b9f\u0bcd\u0b9f\u0bc1\u0baa\u0bcd\u0baa\u0b9f\u0bc1\u0ba4\u0bcd\u0ba4\u0bc1\u0b95",preview:"\u0bae\u0bc1\u0ba9\u0bcd-\u0ba8\u0bcb\u0b95\u0bcd\u0b95\u0bc1",title:"\u0ba4\u0bb2\u0bc8\u0baa\u0bcd\u0baa\u0bc1",general:"\u0baa\u0bca\u0ba4\u0bc1","tab_advanced":"\u0bae\u0bc7\u0ba9\u0bcd\u0bae\u0bc8\u0baf\u0bc1\u0bb1\u0bcd\u0bb1\u0ba4\u0bc1","tab_appearance":"\u0ba4\u0bcb\u0bb1\u0bcd\u0bb1\u0bae\u0bcd","tab_general":"\u0baa\u0bca\u0ba4\u0bc1",width:"Width",height:"Height"});