tinyMCE.addI18n('lb.advimage_dlg',{"image_list":"Billerl\u00ebscht","align_right":"Riets","align_left":"L\u00e9nks","align_textbottom":"\u00cbnnen am Text","align_texttop":"Uewen am Text","align_bottom":"\u00cbnnen","align_middle":"M\u00ebtteg","align_top":"Uewen","align_baseline":"Zeil",align:"Ausriichtung",hspace:"Horizontalen Ofstand",vspace:"Vertikalen Ofstand",dimensions:"Ausmoossen",border:"Rumm",list:"Billerl\u00ebschten",alt:"Beschreiwung",src:"Adress","dialog_title":"Bild af\u00fcgen/beaarbechten","missing_alt":"W\u00ebll Dir wierklech keng Beschreiwung aginn? Best\u00ebmmt Benotzer mat kierperlechen Aschr\u00e4nkungen k\u00ebnnen sou net dorop zougr\u00e4ifen, genau sou d\u00e9i, d\u00e9i een Textbrowser benotzen oder d\'Uweise vu Biller desaktiv\u00e9iert hunn.","example_img":"Ausgesinn vun der Virschau",misc:"Verschiddenes",mouseout:"bei kengem Mauskontakt",mouseover:"bei Mauskontakt","alt_image":"Alternativt Bild","swap_image":"Bild austauschen",map:"Image-Map",id:"ID",rtl:"Riets no l\u00e9nks",ltr:"L\u00e9nks no riets",classes:"Klassen",style:"Format","long_desc":"Ausf\u00e9ierlech Beschreiwung",langcode:"Sproochcode",langdir:"Schr\u00ebftrichtung","constrain_proportions":"S\u00e4iteverh\u00e4ltnis b\u00e4ibehalen",preview:"Virschau",title:"Titel",general:"Allgemeng","tab_advanced":"Erweidert","tab_appearance":"Ausgesinn","tab_general":"Allgemeng",width:"Width",height:"Height"});