tinyMCE.addI18n('ml.advanced_dlg',{"link_list":"Link list","link_is_external":"The URL you entered seems to external link, do you want to add the required http:// prefix?","link_is_email":"The URL you entered seems to be an email address, do you want to add the required mailto: prefix?","link_titlefield":"Title","link_target_blank":"Open link in a new window","link_target_same":"Open link in the same window","link_target":"Target","link_url":"\u0d2c\u0d3e\u0d28\u0d4d\u0d27\u0d35 \u0d35\u0d3f\u0d32\u0d3e\u0d38\u0d02","link_title":"Insert/edit link","image_align_right":"Right","image_align_left":"Left","image_align_textbottom":"Text bottom","image_align_texttop":"Text top","image_align_bottom":"Bottom","image_align_middle":"\u0d28\u0d1f\u0d41\u0d35\u0d3f\u0d32\u0d4d\u200d","image_align_top":"Top","image_align_baseline":"Baseline","image_align":"Alignment","image_hspace":"\u0d24\u0d3f\u0d30\u0d36\u0d4d\u0d1a\u0d40\u0d28 \u0d38\u0d4d\u0d25\u0d32\u0d02","image_vspace":"\u0d32\u0d02\u0d2c \u0d38\u0d4d\u0d25\u0d32\u0d02","image_dimensions":"\u0d05\u0d33\u0d35\u0d41\u0d15\u0d33\u0d4d\u200d","image_alt":"Image description","image_list":"Image list","image_border":"\u0d05\u0d24\u0d3f\u0d30\u0d41\u0d4d","image_src":"Image URL","image_title":"Insert/edit image","charmap_title":"Select custom character","colorpicker_name":"\u0d2a\u0d47\u0d30\u0d41\u0d4d:","colorpicker_color":"\u0d28\u0d3f\u0d31\u0d02:","colorpicker_named_title":"\u0d2a\u0d47\u0d30\u0d3f\u0d1f\u0d4d\u0d1f \u0d28\u0d3f\u0d31\u0d19\u0d4d\u0d19\u0d33\u0d4d\u200d","colorpicker_named_tab":"\u0d2a\u0d47\u0d30\u0d3f\u0d1f\u0d4d\u0d1f","colorpicker_palette_title":"Palette colors","colorpicker_palette_tab":"Palette","colorpicker_picker_title":"Color picker","colorpicker_picker_tab":"Picker","colorpicker_title":"\u0d28\u0d3f\u0d31\u0d02 \u0d24\u0d3f\u0d30\u0d1e\u0d4d\u0d1e\u0d46\u0d1f\u0d41\u0d15\u0d4d\u0d15\u0d41\u0d15","code_wordwrap":"Word wrap","code_title":"HTML Source Editor","anchor_name":"\u0d28\u0d19\u0d4d\u0d15\u0d42\u0d30 \u0d2a\u0d47\u0d30\u0d41\u0d4d","anchor_title":"Insert/edit anchor","about_loaded":"Loaded plugins","about_version":"\u0d2a\u0d24\u0d3f\u0d2a\u0d4d\u0d2a\u0d41\u0d4d","about_author":"Author","about_plugin":"Plugin","about_plugins":"Plugins","about_license":"License","about_help":"\u0d38\u0d39\u0d3e\u0d2f\u0d02","about_general":"About","about_title":"About TinyMCE","anchor_invalid":"Please specify a valid anchor name.","accessibility_help":"Accessibility Help","accessibility_usage_title":"General Usage"});