tinyMCE.addI18n('ch.advanced_dlg',{"link_list":"\u8d85\u8fde\u7ed3\u6e05\u5355","link_is_external":"\u60a8\u8f93\u5165\u7684 URL \u662f\u4e00\u4e2a\u5916\u90e8\u8d85\u8fde\u7ed3\uff0c\u662f\u5426\u8981\u52a0\u4e0a http:// ?","link_is_email":"\u60a8\u8f93\u5165\u7684\u662f\u7535\u5b50\u90ae\u4ef6\u5730\u5740\uff0c\u662f\u5426\u9700\u8981\u52a0 mailto:?","link_titlefield":"\u6807\u9898","link_target_blank":"\u65b0\u89c6\u7a97\u6253\u5f00\u8d85\u8fde\u7ed3","link_target_same":"\u76ee\u524d\u89c6\u7a97\u6253\u5f00\u8d85\u8fde\u7ed3","link_target":"\u76ee\u6807","link_url":"\u8d85\u8fde\u7ed3URL","link_title":"\u63d2\u5165/\u7f16\u8f91\u8d85\u8fde\u7ed3","image_align_right":"\u9760\u53f3","image_align_left":"\u9760\u5de6","image_align_textbottom":"\u6587\u5b57\u4e0b\u65b9","image_align_texttop":"\u6587\u5b57\u4e0a\u65b9","image_align_bottom":"\u9760\u4e0b","image_align_middle":"\u7f6e\u4e2d","image_align_top":"\u9760\u4e0a","image_align_baseline":"\u57fa\u51c6\u7ebf","image_align":"\u5bf9\u9f50\u65b9\u5f0f","image_hspace":"\u6c34\u5e73\u95f4\u8ddd","image_vspace":"\u5782\u76f4\u95f4\u8ddd","image_dimensions":"\u5c3a\u5bf8","image_alt":"\u56fe\u7247\u8bf4\u660e","image_list":"\u56fe\u7247\u6e05\u5355","image_border":"\u8fb9\u6846","image_src":"\u56fe\u7247URL","image_title":"\u63d2\u5165/\u7f16\u8f91\u56fe\u7247","charmap_title":"\u63d2\u5165\u7279\u6b8a\u7b26\u53f7","colorpicker_name":"\u540d\u79f0\uff1a","colorpicker_color":"\u989c\u8272\uff1a","colorpicker_named_title":"\u5e38\u7528\u989c\u8272","colorpicker_named_tab":"\u5e38\u7528\u989c\u8272","colorpicker_palette_title":"WEB\u989c\u8272","colorpicker_palette_tab":"\u5b89\u5168\u8272","colorpicker_picker_title":"\u8c03\u8272\u76d8","colorpicker_picker_tab":"\u8c03\u8272\u76d8","colorpicker_title":"\u9009\u62e9\u989c\u8272","code_wordwrap":"\u81ea\u52a8\u6362\u884c","code_title":"\u4ee3\u7801\u6807\u9898","anchor_name":"\u4e66\u7b7e\u540d\u79f0","anchor_title":"\u63d2\u5165/\u7f16\u8f91\u4e66\u7b7e","about_loaded":"\u5df2\u542f\u7528\u7684\u63d2\u4ef6","about_version":"\u7248\u672c","about_author":"\u4f5c\u8005","about_plugin":"\u63d2\u4ef6","about_plugins":"\u63d2\u4ef6","about_license":"\u6388\u6743","about_help":"\u8bf4\u660e","about_general":"\u5173\u65bc","about_title":"\u5173\u65bc TinyMCE","anchor_invalid":"Please specify a valid anchor name.","accessibility_help":"Accessibility Help","accessibility_usage_title":"General Usage"});