tinyMCE.addI18n('zu.fullpage_dlg',{title:"\u6863\u6848\u5c5e\u6027","meta_tab":"\u4e00\u822c","appearance_tab":"\u5916\u89c2","advanced_tab":"\u9ad8\u7ea7","meta_props":"\u6807\u7b7e( Meta )\u4fe1\u606f",langprops:"\u8bed\u8a00\u4e0e\u7f16\u7801","meta_title":"\u6807\u9898","meta_keywords":"\u5173\u952e\u5b57","meta_description":"\u5185\u5bb9\u8bf4\u660e","meta_robots":"Robots",doctypes:"Doctype",langcode:"\u8bed\u8a00\u7f16\u7801",langdir:"\u8bed\u8a00\u4e66\u5199\u65b9\u5411",ltr:"\u7531\u5de6\u5230\u53f3",rtl:"\u7531\u53f3\u5230\u5de6","xml_pi":"XML\u5ba3\u544a",encoding:"\u5b57\u5143\u7f16\u7801","appearance_bgprops":"\u80cc\u666f\u5c5e\u6027","appearance_marginprops":"Body margins","appearance_linkprops":"\u8fde\u7ed3\u989c\u8272","appearance_textprops":"\u6587\u5b57\u5c5e\u6027",bgcolor:"\u80cc\u666f\u989c\u8272",bgimage:"\u80cc\u666f\u56fe\u7247","left_margin":"\u5de6\u8fb9\u754c","right_margin":"\u53f3\u8fb9\u754c","top_margin":"\u4e0a\u8fb9\u754c","bottom_margin":"\u4e0b\u8fb9\u754c","text_color":"\u6587\u5b57\u989c\u8272","font_size":"\u5b57\u4f53\u5c3a\u5bf8","font_face":"\u5b57\u4f53","link_color":"\u8fde\u7ed3\u989c\u8272","hover_color":"Hover\u989c\u8272","visited_color":"Visited\u989c\u8272","active_color":"Active\u989c\u8272",textcolor:"\u989c\u8272",fontsize:"\u5b57\u4f53\u5927\u5c0f",fontface:"\u5b57\u5f62\u4f53\u7cfb","meta_index_follow":"Index and follow the links","meta_index_nofollow":"Index and don\'t follow the links","meta_noindex_follow":"Do not index but follow the links","meta_noindex_nofollow":"Do not index and don\\\'t follow the links","appearance_style":"\u6837\u5f0f\u8868\u53ca\u6837\u5f0f\u5c5e\u6027",stylesheet:"\u6837\u5f0f\u8868",style:"\u6837\u5f0f",author:"\u4f5c\u8005",copyright:"\u7248\u6743",add:"\u6dfb\u52a0\u65b0\u5143\u7d20",remove:"\u79fb\u9664\u9009\u5b9a\u5143\u7d20",moveup:"\u4e0a\u79fb\u9009\u5b9a\u5143\u7d20",movedown:"\u4e0b\u79fb\u9009\u5b9a\u5143\u7d20","head_elements":"Head elements",info:"\u4fe1\u606f","add_title":"\u67e5\u627e\u5143\u7d20","add_meta":"Meta\u5143\u7d20","add_script":"Script\u5143\u7d20","add_style":"Style\u5143\u7d20","add_link":"Link\u5143\u7d20","add_base":"Base\u5143\u7d20","add_comment":"Comment node","title_element":"\u67e5\u627eelement","script_element":"Script element","style_element":"Style element","base_element":"Base element","link_element":"Link element","meta_element":"Meta element","comment_element":"Comment",src:"Src",language:"\u8bed\u8a00",href:"Href",target:"\u76ee\u6807",type:"\u7c7b\u578b",charset:"\u5b57\u5143\u96c6",defer:"\u5ef6\u7f13",media:"\u5a92\u4f53",properties:"\u5c5e\u6027",name:"\u540d\u79f0",value:"\u503c",content:"\u5185\u5bb9",rel:"Rel",rev:"Rev",hreflang:"Href lang","general_props":"\u4e00\u822c","advanced_props":"\u9ad8\u7ea7"});