tinyMCE.addI18n('ta.style_dlg',{"text_lineheight":"\u0b95\u0bcb\u0b9f\u0bc1 \u0b89\u0baf\u0bb0\u0bae\u0bcd","text_variant":"\u0bae\u0bbe\u0bb1\u0bc1\u0baa\u0bbe\u0b9f\u0bc1","text_style":"\u0baa\u0bbe\u0ba3\u0bbf","text_weight":"\u0b8e\u0b9f\u0bc8","text_size":"\u0b85\u0bb3\u0bb5\u0bc1","text_font":"\u0b8e\u0bb4\u0bc1\u0ba4\u0bcd\u0ba4\u0bc1\u0bb0\u0bc1","text_props":"\u0b89\u0bb0\u0bc8","positioning_tab":"\u0ba8\u0bbf\u0bb2\u0bc8\u0baa\u0bcd\u0baa\u0b9f\u0bc1\u0ba4\u0bcd\u0ba4\u0bb2\u0bcd","list_tab":"\u0baa\u0b9f\u0bcd\u0b9f\u0bbf\u0baf\u0bb2\u0bcd","border_tab":"\u0b95\u0bb0\u0bc8","box_tab":"\u0baa\u0bc6\u0b9f\u0bcd\u0b9f\u0bbf","block_tab":"Block","background_tab":"\u0baa\u0bbf\u0ba9\u0bcd\u0ba9\u0ba3\u0bbf","text_tab":"\u0b89\u0bb0\u0bc8",apply:"Apply",title:"Edit CSS Style",clip:"Clip",placement:"Placement",overflow:"Overflow",zindex:"Z-index",visibility:"Visibility","positioning_type":"\u0bb5\u0b95\u0bc8",position:"Position","bullet_image":"\u0baa\u0bca\u0b9f\u0bcd\u0b9f\u0bc1\u0baa\u0bcd \u0baa\u0b9f\u0bae\u0bcd","list_type":"\u0bb5\u0b95\u0bc8",color:"\u0ba8\u0bbf\u0bb1\u0bae\u0bcd",height:"\u0b89\u0baf\u0bb0\u0bae\u0bcd",width:"\u0b85\u0b95\u0bb2\u0bae\u0bcd",style:"\u0baa\u0bbe\u0ba3\u0bbf",margin:"\u0b93\u0bb0\u0bae\u0bcd",left:"\u0b87\u0b9f\u0ba4\u0bc1",bottom:"\u0b95\u0bc0\u0bb4\u0bcd",right:"\u0bb5\u0bb2\u0ba4\u0bc1",top:"\u0bae\u0bc7\u0bb2\u0bcd",same:"Same for all",padding:"Padding","box_clear":"Clear","box_float":"Float","box_height":"\u0b89\u0baf\u0bb0\u0bae\u0bcd","box_width":"\u0b85\u0b95\u0bb2\u0bae\u0bcd","block_display":"Display","block_whitespace":"Whitespace","block_text_indent":"Text indent","block_text_align":"Text align","block_vertical_alignment":"Vertical alignment","block_letterspacing":"Letter spacing","block_wordspacing":"Word spacing","background_vpos":"Vertical position","background_hpos":"Horizontal position","background_attachment":"Attachment","background_repeat":"Repeat","background_image":"Background image","background_color":"Background color","text_none":"\u0b8f\u0ba4\u0bc1\u0bae\u0bbf\u0bb2\u0bcd\u0bb2\u0bc8","text_blink":"blink","text_case":"Case","text_striketrough":"strikethrough","text_underline":"\u0b85\u0b9f\u0bbf\u0b95\u0bcd\u0b95\u0bcb\u0b9f\u0bc1","text_overline":"overline","text_decoration":"Decoration","text_color":"\u0ba8\u0bbf\u0bb1\u0bae\u0bcd",text:"Text",background:"Background",block:"Block",box:"Box",border:"Border",list:"List"});