tinyMCE.addI18n('ta.media_dlg',{list:"\u0baa\u0b9f\u0bcd\u0b9f\u0bbf\u0baf\u0bb2\u0bcd",file:"\u0b95\u0bcb\u0baa\u0bcd\u0baa\u0bc1/\u0b87\u0ba3\u0bc8\u0baf\u0bae\u0bc1\u0b95\u0bb5\u0bb0\u0bbf",advanced:"\u0bae\u0bc7\u0ba9\u0bcd\u0bae\u0bc8\u0baf\u0bc1\u0bb1\u0bcd\u0bb1\u0ba4\u0bc1",general:"\u0baa\u0bca\u0ba4\u0bc1",title:"Insert / edit embedded media","align_top_left":"\u0bae\u0bc7\u0bb2\u0bcd \u0b87\u0b9f\u0bae\u0bcd","align_center":"\u0bae\u0bc8\u0baf\u0bae\u0bcd","align_left":"\u0b87\u0b9f\u0bae\u0bcd","align_bottom":"\u0b95\u0bc0\u0bb4\u0bcd","align_right":"\u0bb5\u0bb2\u0bae\u0bcd","align_top":"\u0bae\u0bc7\u0bb2\u0bcd","qt_stream_warn":"Streamed rtsp resources should be added to the QT Src field under the advanced tab.\nYou should also add a non streamed version to the Src field..",qtsrc:"QT Src",progress:"Progress",sound:"Sound",swstretchvalign:"Stretch V-Align",swstretchhalign:"Stretch H-Align",swstretchstyle:"Stretch style",scriptcallbacks:"Script callbacks","align_top_right":"\u0bae\u0bc7\u0bb2\u0bcd \u0bb5\u0bb2\u0bae\u0bcd",uimode:"UI Mode",rate:"Rate",playcount:"Play count",defaultframe:"Default frame",currentposition:"Current position",currentmarker:"Current marker",captioningid:"Captioning id",baseurl:"Base URL",balance:"Balance",windowlessvideo:"Windowless video",stretchtofit:"Stretch to fit",mute:"Mute",invokeurls:"Invoke URLs",fullscreen:"Fullscreen",enabled:"\u0b87\u0baf\u0bb2\u0bc1\u0bae\u0bc8\u0baa\u0bcd\u0baa\u0b9f\u0bc1\u0ba4\u0bcd\u0ba4\u0baa\u0bcd\u0baa\u0b9f\u0bcd\u0b9f\u0ba4\u0bc1",autostart:"Auto start",volume:"Volume",target:"\u0b87\u0bb2\u0b95\u0bcd\u0b95\u0bc1",qtsrcchokespeed:"Choke speed",href:"Href",endtime:"End time",starttime:"Start time",enablejavascript:"Enable JavaScript",correction:"No correction",targetcache:"Target cache",playeveryframe:"Play every frame",kioskmode:"Kiosk mode",controller:"\u0b95\u0b9f\u0bcd\u0b9f\u0bc1\u0baa\u0bcd\u0baa\u0b9f\u0bc1\u0ba4\u0bcd\u0ba4\u0bbf",menu:"Show menu",loop:"\u0b95\u0ba3\u0bcd\u0ba3\u0bbf",play:"Auto play",hspace:"H-Space",vspace:"V-Space","class_name":"Class",name:"\u0baa\u0bc6\u0baf\u0bb0\u0bcd",id:"Id",type:"\u0bb5\u0b95\u0bc8",size:"\u0b85\u0bb3\u0bb5\u0bc1\u0b95\u0bb3\u0bcd",preview:"\u0bae\u0bc1\u0ba9\u0bcd-\u0ba8\u0bcb\u0b95\u0bcd\u0b95\u0bc1","constrain_proportions":"Constrain proportions",controls:"Controls",numloop:"Num loops",console:"Console",cache:"\u0baa\u0ba4\u0bc1\u0b95\u0bcd\u0b95\u0bc1\u0ba8\u0bbf\u0ba9\u0bc8\u0bb5\u0b95\u0bae\u0bcd",autohref:"AutoHREF",liveconnect:"SWLiveConnect",flashvars:"Flashvars",base:"Base",bgcolor:"\u0baa\u0bbf\u0ba9\u0bcd\u0ba9\u0ba3\u0bbf",wmode:"WMode",salign:"SAlign",align:"Align",scale:"Scale",quality:"Quality",shuffle:"Shuffle",prefetch:"Prefetch",nojava:"java \u0b87\u0bb2\u0bcd\u0bb2\u0bc8",maintainaspect:"Maintain aspect",imagestatus:"\u0baa\u0b9f\u0ba4\u0bcd\u0ba4\u0bbf\u0ba9\u0bcd \u0ba8\u0bbf\u0bb2\u0bc8",center:"\u0bae\u0bc8\u0baf\u0bae\u0bcd",autogotourl:"Auto goto URL","shockwave_options":"Shockwave options","rmp_options":"Real media player options","wmp_options":"Windows media player options","qt_options":"Quicktime options","flash_options":"Flash options",hidden:"Hidden","align_bottom_left":"Bottom left","align_bottom_right":"Bottom right",source:"\u0bae\u0bc2\u0bb2\u0bae\u0bcd",flash:"",quicktime:"","embedded_audio_options":"Embedded Audio Options",windowsmedia:"",realmedia:"",shockwave:"",audio:"",video:"","html5_video_options":"HTML5 Video Options",altsource1:"Alternative source 1",altsource2:"Alternative source 2",preload:"Preload",poster:"Poster","html5_audio_options":"Audio Options","preload_none":"Don\'t Preload","preload_metadata":"Preload video metadata","preload_auto":"Let user\'s browser decide",iframe:"",embeddedaudio:""});