tinyMCE.addI18n('lb.searchreplace_dlg',{findwhat:"Ze sichenden Text",replacewith:"Ersetzen duerch",direction:"Sichrichtung",up:"No uewen",down:"No \u00ebnnen",mcase:"Grouss-/Klengschreiwung beuechten",findnext:"Weidersichen",allreplaced:"All d\'Virkomme vun der Zeechekette goufen ersat.","searchnext_desc":"Weidersichen",notfound:"D\'Sich ass um Enn ukomm. D\'Zeechekette konnt net fonnt ginn.","search_title":"Sichen","replace_title":"Sichen/Ersetzen",replaceall:"All ersetzen",replace:"Ersetzen"});