tinyMCE.addI18n('zu.simple',{"cleanup_desc":"\u6e05\u9664\u591a\u4f59\u4ee3\u7801","redo_desc":"\u91cd\u505a(Ctrl+Y)","undo_desc":"\u64a4\u9500(Ctrl+Z)","numlist_desc":"\u7f16\u53f7","bullist_desc":"\u4e13\u6848\u7b26\u53f7","striketrough_desc":"\u5220\u9664\u7ebf","underline_desc":"\u5e95\u7ebf(Ctrl+U)","italic_desc":"\u659c\u4f53(Ctrl+I)","bold_desc":"\u9ed1\u4f53(Ctrl+B)"});