tinyMCE.addI18n('tt.style_dlg',{"text_lineheight":"\u884c\u9ad8","text_variant":"\u8b8a\u9ad4","text_style":"\u6a23\u5f0f","text_weight":"\u5bec\u5ea6","text_size":"\u5927\u5c0f","text_font":"\u5b57\u9ad4","text_props":"\u6587\u5b57","positioning_tab":"\u4f4d\u7f6e","list_tab":"\u5217\u8868","border_tab":"\u908a\u6846","box_tab":"\u76d2\u6a21\u578b","block_tab":"\u5340\u584a","background_tab":"\u80cc\u666f","text_tab":"\u6587\u5b57",apply:"\u61c9\u7528",title:"\u7de8\u8f2f CSS \u6a23\u5f0f\u8868",clip:"\u526a\u8f2f",placement:"\u4f48\u7f6e",overflow:"\u6ea2\u51fa",zindex:"Z\u5ea7\u6a19",visibility:"\u662f\u5426\u53ef\u898b","positioning_type":"\u4f4d\u7f6e\u985e\u578b",position:"\u5716\u7247\u4f4d\u7f6e","bullet_image":"\u6e05\u55ae\u5716\u7247","list_type":"\u5217\u8868\u985e\u578b",color:"\u9854\u8272",height:"\u9ad8\u5ea6",width:"\u5bec\u5ea6",style:"\u6a23\u5f0f",margin:"\u908a\u8ddd",left:"\u5de6\u5074",bottom:"\u5e95\u90e8",right:"\u53f3\u5074",top:"\u9802\u90e8",same:"\u5168\u90e8\u76f8\u540c",padding:"\u5167\u908a\u8ddd","box_clear":"\u6e05\u9664","box_float":"\u6d6e\u52d5","box_height":"\u9ad8\u5ea6","box_width":"\u5bec\u5ea6","block_display":"\u986f\u793a\u65b9\u5f0f","block_whitespace":"\u7a7a\u683c","block_text_indent":"\u6587\u5b57\u7e2e\u6392","block_text_align":"\u6587\u5b57\u5c0d\u9f4a","block_vertical_alignment":"\u5782\u76f4\u5c0d\u9f4a\u65b9\u5f0f","block_letterspacing":"\u5b57\u6bcd\u9593\u8ddd","block_wordspacing":"\u8a5e\u9593\u8ddd","background_vpos":"\u5782\u76f4\u4f4d\u7f6e","background_hpos":"\u6c34\u5e73\u4f4d\u7f6e","background_attachment":"\u9644\u4ef6","background_repeat":"\u91cd\u5fa9","background_image":"\u80cc\u666f\u5716\u7247","background_color":"\u80cc\u666f\u9854\u8272","text_none":"\u7121","text_blink":"\u9583\u720d","text_case":"\u5b57\u9ad4","text_striketrough":"\u4e2d\u5283\u7dda","text_underline":"\u5e95\u7dda","text_overline":"\u4e0a\u5283\u7dda","text_decoration":"\u88dd\u98fe","text_color":"\u9854\u8272",text:"Text",background:"Background",block:"Block",box:"Box",border:"Border",list:"List"});