tinyMCE.addI18n('tn.advanced',{"underline_desc":"Sega-tselana (Ctrl+U)","italic_desc":"Tseketa (Ctrl+I)","bold_desc":"Bokima (Ctrl+B)",dd:"Thaloso  ya Kaedi",dt:"Thaloso ya Theme ",samp:"Sampole ya khoudi",code:"khoudi",blockquote:"Blockquote",h6:"Sethogo 6",h5:"Sethogo 5",h4:"Sethogo 4",h3:"Sethogo 3",h2:"Sethogo 2",h1:"Sethogo 1",pre:"Fomatilwe",address:"Aterese",div:"Div",paragraph:"Pharakerafo",block:"Fomete ",fontdefault:"Lelwapa la mokwalo","font_size":"Bolekano jwa mokwalo","style_select":"Matlaela","more_colors":"Mebala e mentsi","toolbar_focus":"Tlolela kwa thulusong ya dibathene - Alt+Q, tlolela ko sebaakanying - Alt-Z, Tlolela kwa phatlheng ya elemente  - Alt-X",newdocument:"A o netefatsa gore o batla go sutlha diteng tsotlhe",path:"Phatlha","clipboard_msg":"Kopa/Sega/Kgomaretsa ga e yo mo Mozila Firefox A o batla molaetsa ka lebaka le?","blockquote_desc":"Blockquote","help_desc":"Thuso","newdocument_desc":"Tokomente e Ntshwa","image_props_desc":"Ditlhagotshedimosetso tsa setswantsho","paste_desc":"Kgomaretsa","copy_desc":"Kopa","cut_desc":"Sega","anchor_desc":"Tsenya/Baakanya anchor","visualaid_desc":"Kgothakgotha melawana","charmap_desc":"Tsenya boitirelo jwa khareketa","backcolor_desc":"Thopha mmala wa kwa-morago ","forecolor_desc":"Thopha mmala wa mafoko","custom1_desc":"Ntsha kaedi ya boitirelo","removeformat_desc":"Ntsha Boalo","hr_desc":"Tsenya rula e robetseng","sup_desc":"Godimonyana","sub_desc":"Tlasenyana","code_desc":"Baakanya HTML Source","cleanup_desc":"Kolomaka khoudi e meragaraga ","image_desc":"Tsenay/ Baakanya setswantsho","unlink_desc":"Lomolola ","link_desc":"Tsenya/Baakanya lomaganya","redo_desc":"Dira-gape (Ctrl+Y)","undo_desc":"Dirolola(Ctrl+Z)","indent_desc":"Moteng","outdent_desc":"Kwantle","numlist_desc":"Tatelano e rulagantsweng","bullist_desc":"Tatelano e thakathakaneng","justifyfull_desc":"Beela go tletse","justifyright_desc":"Beela kwa mojeng","justifycenter_desc":"Beela fagare","justifyleft_desc":"Beela kwa Molemeng","striketrough_desc":"Sega-bogare","anchor_delta_height":"","anchor_delta_width":"","charmap_delta_height":"","charmap_delta_width":"","colorpicker_delta_height":"","colorpicker_delta_width":"","link_delta_height":"","link_delta_width":"","image_delta_height":"","image_delta_width":"","help_shortcut":"Press ALT-F10 for toolbar. Press ALT-0 for help","rich_text_area":"Rich Text Area","shortcuts_desc":"Accessability Help",toolbar:"Toolbar"});