tinyMCE.addI18n('lb.emotions_dlg',{cry:"Kr\u00e4ischend",cool:"Cool",desc:"Smileyen",title:"Smiley af\u00fcgen",yell:"Br\u00ebllend",wink:"Zwinkernd",undecided:"Onentschloss","tongue_out":"Zong eraus",surprised:"Iwwerrascht",smile:"Laachend",sealed:"Verschlossen","money_mouth":"Suen",laughing:"Laachend",kiss:"Kussend",innocent:"Onsch\u00eblleg",frown:"D\'Stir ronzelend","foot_in_mouth":"Eragefall",embarassed:"Gen\u00e9iert"});