tinyMCE.addI18n('sc.style_dlg',{"text_lineheight":"\u884c\u9ad8","text_variant":"\u53d8\u4f53","text_style":"\u6837\u5f0f","text_weight":"\u5bbd\u5ea6","text_size":"\u5c3a\u5bf8","text_font":"\u5b57\u4f53","text_props":"\u6587\u5b57","positioning_tab":"\u4f4d\u7f6e","list_tab":"\u5217\u8868","border_tab":"\u8fb9\u6846","box_tab":"\u7bb1\u578b","block_tab":"\u5757","background_tab":"\u80cc\u666f","text_tab":"\u6587\u5b57",apply:"\u5e94\u7528",title:"\u7f16\u8f91CSS\u6837\u5f0f\u8868\u5355",clip:"\u526a\u8f91",placement:"\u5e03\u7f6e",overflow:"\u6ea2\u51fa",zindex:"Z\u8f74\u6df1\u5ea6",visibility:"\u53ef\u89c1\u6027","positioning_type":"\u7c7b\u578b",position:"\u56fe\u793a\u4f4d\u7f6e","bullet_image":"\u4e13\u6848\u56fe\u793a","list_type":"\u7c7b\u578b",color:"\u989c\u8272",height:"\u9ad8\u5ea6",width:"\u5bbd\u5ea6",style:"\u6837\u5f0f",margin:"\u8fb9\u754c",left:"\u9760\u5de6",bottom:"\u4e0b\u65b9",right:"\u9760\u53f3",top:"\u4e0a\u65b9",same:"\u5168\u90e8\u4e00\u6837",padding:"\u7559\u767d","box_clear":"\u6e05\u9664","box_float":"\u6d6e\u52a8","box_height":"\u9ad8\u5ea6","box_width":"\u5bbd\u5ea6","block_display":"\u663e\u793a\u65b9\u5f0f","block_whitespace":"\u7a7a\u767d","block_text_indent":"\u6587\u5b57\u7f29\u6392","block_text_align":"\u6587\u5b57\u5bf9\u9f50","block_vertical_alignment":"\u6c34\u51c6\u5bf9\u9f50\u65b9\u5f0f","block_letterspacing":"\u5b57\u5143\u95f4\u8ddd","block_wordspacing":"\u5355\u5b57\u95f4\u8ddd","background_vpos":"\u6c34\u51c6\u4f4d\u7f6e","background_hpos":"\u5782\u76f4\u4f4d\u7f6e","background_attachment":"\u9644\u4ef6","background_repeat":"\u91cd\u590d","background_image":"\u80cc\u666f\u56fe\u7247","background_color":"\u80cc\u666f\u989c\u8272","text_none":"\u65e0","text_blink":"\u95ea\u70c1","text_case":"\u5b57\u4f53","text_striketrough":"\u5220\u9664\u7ebf","text_underline":"\u5e95\u7ebf","text_overline":"\u4e0a\u5212\u7ebf","text_decoration":"\u4fee\u9970","text_color":"\u989c\u8272",text:"Text",background:"Background",block:"Block",box:"Box",border:"Border",list:"List"});