tinyMCE.addI18n('zu.xhtmlxtras_dlg',{"attribs_title":"\u63d2\u5165/\u7f16\u8f91\u5c5e\u6027","option_rtl":"\u7531\u53f3\u5230\u5de6","option_ltr":"\u7531\u5de6\u5230\u53f3","insert_date":"\u63d2\u5165\u73b0\u5728\u65e5\u671f/\u65f6\u95f4",remove:"\u5220\u9664","title_cite_element":"\u5f15\u6587\u5143\u7d20","title_abbr_element":"\u7f29\u5199\u5143\u7d20","title_acronym_element":"\u9996\u5b57\u7f29\u5199\u5143\u7d20","title_del_element":"\u5220\u9664\u5143\u7d20","title_ins_element":"\u63d2\u5165\u5143\u7d20","fieldset_events_tab":"\u5143\u7d20\u4e8b\u4ef6","fieldset_attrib_tab":"\u5143\u7d20\u5c5e\u6027","fieldset_general_tab":"\u4e00\u822c","events_tab":"\u4e8b\u4ef6","attrib_tab":"\u5c5e\u6027","general_tab":"\u4e00\u822c","attribute_attrib_tab":"\u5c5e\u6027","attribute_events_tab":"\u4e8b\u4ef6","attribute_label_accesskey":"\u5feb\u901f\u952e","attribute_label_tabindex":"Tab\u7d22\u5f15","attribute_label_langcode":"\u8bed\u8a00","attribute_option_rtl":"\u7531\u53f3\u5230\u5de6","attribute_option_ltr":"\u7531\u5de6\u5230\u53f3","attribute_label_langdir":"\u6587\u5b57\u4e66\u5199\u65b9\u5411","attribute_label_datetime":"\u65e5\u671f/\u65f6\u95f4","attribute_label_cite":"\u5f15\u6587","attribute_label_style":"\u6837\u5f0f","attribute_label_class":"\u7c7b\u578b","attribute_label_id":"ID","attribute_label_title":"\u67e5\u627e"});