tinyMCE.addI18n('ta.fullpage_dlg',{title:"\u0b86\u0bb5\u0ba3 \u0b95\u0bc1\u0ba3\u0bbe\u0ba4\u0bbf\u0b9a\u0baf\u0b99\u0bcd\u0b95\u0bb3\u0bcd","meta_tab":"\u0baa\u0bca\u0ba4\u0bc1","appearance_tab":"\u0ba4\u0bcb\u0bb1\u0bcd\u0bb1\u0bae\u0bcd","advanced_tab":"\u0bae\u0bc7\u0ba9\u0bcd\u0bae\u0bc8\u0baf\u0bc1\u0bb1\u0bcd\u0bb1\u0ba4\u0bc1","meta_props":"\u0bae\u0bc0 \u0ba4\u0b95\u0bb5\u0bb2\u0bcd",langprops:"\u0bae\u0bca\u0bb4\u0bbf \u0bae\u0bb1\u0bcd\u0bb1\u0bc1\u0bae\u0bcd \u0b95\u0bc1\u0bb1\u0bbf\u0baf\u0bc0\u0b9f\u0bbe\u0b95\u0bcd\u0b95\u0bae\u0bcd","meta_title":"\u0ba4\u0bb2\u0bc8\u0baa\u0bcd\u0baa\u0bc1","meta_keywords":"\u0bae\u0bc1\u0ba4\u0ba9\u0bcd\u0bae\u0bc8\u0b9a\u0bcd\u0b9a\u0bca\u0bb1\u0bcd\u0b95\u0bb3\u0bcd","meta_description":"\u0bb5\u0bbf\u0bb5\u0bb0\u0bae\u0bcd","meta_robots":"Robots",doctypes:"\u0b86\u0bb5\u0ba3\u0bb5\u0b95\u0bc8",langcode:"\u0bae\u0bca\u0bb4\u0bbf\u0b95\u0bcd \u0b95\u0bc1\u0bb1\u0bbf\u0baf\u0bc0\u0b9f\u0bc1",langdir:"\u0bae\u0bca\u0bb4\u0bbf\u0ba4\u0bcd \u0ba4\u0bbf\u0b9a\u0bc8",ltr:"\u0b87\u0b9f\u0bae\u0bbf\u0bb0\u0bc1\u0ba8\u0bcd\u0ba4\u0bc1 \u0bb5\u0bb2\u0bae\u0bcd",rtl:"\u0bb5\u0bb2\u0bae\u0bbf\u0bb0\u0bc1\u0ba8\u0bcd\u0ba4\u0bc1 \u0b87\u0b9f\u0bae\u0bcd","xml_pi":"XML declaration",encoding:"\u0b89\u0bb0\u0bc1/\u0b8e\u0bb4\u0bc1\u0ba4\u0bcd\u0ba4\u0bc1 \u0b95\u0bc1\u0bb0\u0bbf\u0baf\u0bc0\u0b9f\u0bbe\u0b95\u0bcd\u0b95\u0bae\u0bcd","appearance_bgprops":"\u0baa\u0bbf\u0ba9\u0bcd\u0ba9\u0ba3\u0bbf \u0b95\u0bc1\u0ba3\u0bbe\u0ba4\u0bbf\u0b9a\u0baf\u0b99\u0bcd\u0b95\u0bb3\u0bcd","appearance_marginprops":"\u0b89\u0b9f\u0bb2\u0bcd \u0b93\u0bb0\u0b99\u0bcd\u0b95\u0bb3\u0bcd","appearance_linkprops":"\u0b87\u0ba3\u0bc8\u0baa\u0bcd\u0baa\u0bc1 \u0ba8\u0bbf\u0bb1\u0b99\u0bcd\u0b95\u0bb3\u0bcd","appearance_textprops":"\u0b89\u0bb0\u0bc8 \u0b95\u0bc1\u0ba3\u0bbe\u0ba4\u0bbf\u0b9a\u0baf\u0b99\u0bcd\u0b95\u0bb3\u0bcd",bgcolor:"\u0baa\u0bbf\u0ba9\u0bcd\u0ba9\u0ba3\u0bbf \u0ba8\u0bbf\u0bb1\u0bae\u0bcd",bgimage:"\u0baa\u0bbf\u0ba9\u0bcd\u0ba9\u0ba3\u0bbf\u0baa\u0bcd \u0baa\u0b9f\u0bae\u0bcd","left_margin":"\u0b87\u0b9f \u0b93\u0bb0\u0bae\u0bcd","right_margin":"\u0bb5\u0bb2 \u0b93\u0bb0\u0bae\u0bcd","top_margin":"\u0bae\u0bc7\u0bb2\u0bcd \u0b93\u0bb0\u0bae\u0bcd","bottom_margin":"\u0b95\u0bc0\u0bb4\u0bcd \u0b93\u0bb0\u0bae\u0bcd","text_color":"\u0b89\u0bb0\u0bc8 \u0ba8\u0bbf\u0bb1\u0bae\u0bcd","font_size":"\u0b89\u0bb0\u0bc1 \u0b85\u0bb3\u0bb5\u0bc1","font_face":"Font face","link_color":"\u0b87\u0ba3\u0bc8\u0baa\u0bcd\u0baa\u0bc1 \u0ba8\u0bbf\u0bb1\u0bae\u0bcd","hover_color":"Hover color","visited_color":"Visited color","active_color":"Active color",textcolor:"\u0ba8\u0bbf\u0bb1\u0bae\u0bcd",fontsize:"\u0b89\u0bb0\u0bc1 \u0b85\u0bb3\u0bb5\u0bc1",fontface:"Font family","meta_index_follow":"Index and follow the links","meta_index_nofollow":"Index and don\'t follow the links","meta_noindex_follow":"Do not index but follow the links","meta_noindex_nofollow":"Do not index and don\\\'t follow the links","appearance_style":"Stylesheet and style properties",stylesheet:"Stylesheet",style:"Style",author:"Author",copyright:"Copyright",add:"Add new element",remove:"Remove selected element",moveup:"Move selected element up",movedown:"Move selected element down","head_elements":"Head elements",info:"\u0ba4\u0b95\u0bb5\u0bb2\u0bcd","add_title":"","add_meta":"Meta element","add_script":"Script element","add_style":"Style element","add_link":"Link element","add_base":"Base element","add_comment":"Comment node","title_element":"Title element","script_element":"Script element","style_element":"Style element","base_element":"Base element","link_element":"Link element","meta_element":"Meta element","comment_element":"Comment",src:"Src",language:"Language",href:"Href",target:"Target",type:"Type",charset:"Charset",defer:"Defer",media:"Media",properties:"Properties",name:"\u0baa\u0bc6\u0baf\u0bb0\u0bcd",value:"\u0baa\u0bc6\u0bb1\u0bc1\u0bae\u0bbe\u0ba9\u0bae\u0bcd",content:"Content",rel:"Rel",rev:"Rev",hreflang:"Href lang","general_props":"\u0baa\u0bca\u0ba4\u0bc1","advanced_props":"\u0bae\u0bc7\u0ba9\u0bcd\u0bae\u0bc8\u0baf\u0bc1\u0bb1\u0bcd\u0bb1\u0ba4\u0bc1"});