tinyMCE.addI18n('lb.table_dlg',{"rules_border":"all 4 S\u00e4iten (Bord)","rules_box":"all 4 S\u00e4iten (Box)","rules_vsides":"l\u00e9nks a riets","rules_rhs":"n\u00ebmmen riets","rules_lhs":"n\u00ebmmen l\u00e9nks","rules_hsides":"uewen an \u00ebnnen","rules_below":"n\u00ebmmen \u00ebnnen","rules_above":"n\u00ebmmen uewen","rules_void":"keen",rules:"Gitter","frame_all":"zw\u00ebschen allen Zellen","frame_cols":"zw\u00ebschen Spalten","frame_rows":"zw\u00ebschen Zeilen","frame_groups":"zw\u00ebschen Gruppen","frame_none":"keng",frame:"Rumm",caption:"Beschr\u00ebftung vun der Tabelle","missing_scope":"W\u00ebllt Dir wierklech keng Bez\u00e9iung fir d\u00ebs Iwwerschr\u00ebft uginn? Benotzer mat kierperlechen Aschr\u00e4nkungen k\u00ebnne Schwieregkeeten hunn, den Inhalt vun der Tabelle ze verstoen.","cell_limit":"Dir hutt d\u00e9i maximal Zellenzuel vun {$cells} iwwerschratt.","row_limit":"Dir hutt d\u00e9i maximal Zeilenzuel vun {$rows} iwwerschratt.","col_limit":"Dir hutt d\u00e9i maximal Spaltenzuel vun {$cols} iwwerschratt.",colgroup:"Horizontal grupp\u00e9ieren",rowgroup:"Vertikal grupp\u00e9ieren",scope:"Bezuch",tfoot:"Tabellefouss",tbody:"Tabelleninhalt",thead:"Tabellekapp","row_all":"All d\'Zeilen ver\u00e4nneren","row_even":"Grued Zeilen ver\u00e4nneren","row_odd":"Ongrued Zeilen ver\u00e4nneren","row_row":"D\u00ebs Zeil ver\u00e4nneren","cell_all":"All Zellen der Tabelle ver\u00e4nneren","cell_row":"All Zellen an d\u00ebser Zeil ver\u00e4nneren","cell_cell":"D\u00ebs Zell ver\u00e4nneren",th:"Iwwerschr\u00ebft",td:"Textzell",summary:"Zesummefaassung",bgimage:"Hannergrondbild",rtl:"Riets no l\u00e9nks",ltr:"L\u00e9nks no riets",mime:"MIME-Typ vum Inhalt",langcode:"Sproochecode",langdir:"Schr\u00ebftrichtung",style:"Format",id:"ID","merge_cells_title":"Zelle vereenen",bgcolor:"Hannergrondfuerf",bordercolor:"Fuerf vun der Rumm","align_bottom":"\u00cbnnen","align_top":"Uewen",valign:"Vertikal Ausriichtung","cell_type":"Zellentyp","cell_title":"Eegeschafte vun der Zell","row_title":"Eegeschafte vun der Zeil","align_middle":"M\u00ebtteg","align_right":"Riets","align_left":"L\u00e9nks","align_default":"Standard",align:"Ausriichtung",border:"Rumm",cellpadding:"Ofstand innerhalb vun den Zellen",cellspacing:"Zellenofstand",rows:"Zeilen",cols:"Spalten",height:"H\u00e9icht",width:"Breet",title:"Tabelle af\u00fcgen/beaarbechten",rowtype:"Grupp\u00e9ierung","advanced_props":"Erweidert Astellungen","general_props":"Allgemeng Astellungen","advanced_tab":"Erweidert","general_tab":"Allgemeng","cell_col":"Update all cells in column"});