tinyMCE.addI18n('zh.media_dlg',{list:"\u5217\u8868",file:"\u6587\u4ef6/URL",advanced:"\u9ad8\u7ea7",general:"\u666e\u901a",title:"\u63d2\u5165/\u7f16\u8f91\u5d4c\u5165\u5a92\u4f53","align_top_left":"\u5de6\u4e0a","align_center":"\u5c45\u4e2d","align_left":"\u9760\u5de6","align_bottom":"\u9760\u4e0b","align_right":"\u9760\u53f3","align_top":"\u9760\u4e0a","qt_stream_warn":"\u6d41\u5a92\u4f53RTSP\u8d44\u6e90\u5e94\u5728\u2018\u9ad8\u7ea7\u2019\u4e2d\u7684QT src\u680f\u76ee\u4e2d\u586b\u5199\u3002\n\u540c\u65f6\u5728src\u680f\u4f4d\u4e2d\u586b\u5199\u975e\u6d41\u5a92\u4f53\u7f51\u5740\u3002",qtsrc:"QT src",progress:"\u8fdb\u5ea6",sound:"\u58f0\u97f3",swstretchvalign:"\u8c03\u6574\u81f3\u5782\u76f4\u5bf9\u9f50",swstretchhalign:"\u8c03\u6574\u81f3\u6c34\u5e73\u5bf9\u9f50",swstretchstyle:"\u8c03\u6574\u6837\u5f0f",scriptcallbacks:"Script\u8c03\u7528","align_top_right":"\u53f3\u4e0a",uimode:"\u9762\u677f\u6a21\u5f0f",rate:"\u6bd4\u4f8b",playcount:"\u64ad\u653e\u6b21\u6570",defaultframe:"\u9884\u8bbe\u753b\u9762",currentposition:"\u5f53\u524d\u4f4d\u7f6e",currentmarker:"\u5f53\u524d\u6807\u8bb0",captioningid:"\u5b57\u5e55ID",baseurl:"\u6839URL",balance:"\u5e73\u8861",windowlessvideo:"\u65e0\u7a97\u53e3\u64ad\u653e",stretchtofit:"\u8c03\u81f3\u6700\u4f73\u5927\u5c0f",mute:"\u9759\u97f3",invokeurls:"\u5f15\u7528\u7684URLs",fullscreen:"\u5168\u5c4f",enabled:"\u53ef\u7528",autostart:"\u81ea\u52a8\u64ad\u653e",volume:"\u97f3\u91cf",target:"\u76ee\u6807",qtsrcchokespeed:"\u9650\u5236\u901f\u5ea6",href:"\u8d85\u94fe\u63a5",endtime:"\u7ed3\u675f\u65f6\u95f4",starttime:"\u5f00\u59cb\u65f6\u95f4",enablejavascript:"\u542f\u7528JavaScript",correction:"\u66f4\u6b63",targetcache:"\u76ee\u6807\u7f13\u5b58",playeveryframe:"\u9010\u683c\u64ad\u653e",kioskmode:"Kiosk\u6a21\u5f0f",controller:"\u63a7\u5236\u53f0",menu:"\u663e\u793a\u83dc\u5355",loop:"\u5faa\u73af\u64ad\u653e",play:"\u81ea\u52a8\u64ad\u653e",hspace:"\u6c34\u5e73\u95f4\u8ddd",vspace:"\u5782\u76f4\u95f4\u8ddd","class_name":"\u7c7b",name:"\u540d\u79f0",id:"ID",type:"\u7c7b\u578b",size:"\u5927\u5c0f",preview:"\u9884\u89c8","constrain_proportions":"\u56fa\u5b9a\u6bd4\u4f8b",controls:"\u63a7\u5236",numloop:"\u5faa\u73af\u6b21\u6570",console:"\u63a7\u5236\u53f0",cache:"\u7f13\u5b58",autohref:"\u81ea\u52a8\u8bbe\u7f6e\u8d85\u94fe\u63a5",liveconnect:"SWLiveConnect",flashvars:"Flash\u53c2\u6570",base:"\u6839",bgcolor:"\u80cc\u666f\u989c\u8272",wmode:"\u7a97\u53e3\u6a21\u5f0f",salign:"\u5bf9\u9f50\u4f4d\u7f6e",align:"\u5bf9\u9f50",scale:"\u7f29\u653e",quality:"\u54c1\u8d28",shuffle:"\u968f\u673a",prefetch:"\u9884\u8f7d",nojava:"\u7981\u6b62Java",maintainaspect:"\u56fa\u5b9a\u6bd4\u4f8b",imagestatus:"\u56fe\u7247\u72b6\u6001",center:"\u5c45\u4e2d",autogotourl:"\u81ea\u52a8\u8df3\u8f6cURL","shockwave_options":"Shockwave\u9009\u9879","rmp_options":"Real Media Player\u9009\u9879","wmp_options":"Windows Media Player\u9009\u9879","qt_options":"Quick Time\u9009\u9879","flash_options":"Flash\u9009\u9879",hidden:"\u9690\u85cf","align_bottom_left":"\u5de6\u4e0b","align_bottom_right":"\u53f3\u4e0b",flash:"Flash",quicktime:"QuickTime","embedded_audio_options":"\u5d4c\u5165\u58f0\u97f3\u9009\u9879",windowsmedia:"Windows Media",realmedia:"Real Media",shockwave:"Shockwave",audio:"HTML5\u97f3\u9891",video:"HTML5\u89c6\u9891","html5_video_options":"HTML5\u89c6\u9891\u9009\u9879",altsource1:"\u66ff\u4ee3\u6765\u6e901",altsource2:"\u66ff\u4ee3\u6765\u6e902",preload:"\u9884\u8f7d\u5165",poster:"\u5f71\u7247\u7f29\u56fe",source:"\u6e90","html5_audio_options":"\u58f0\u97f3\u9009\u9879","preload_none":"\u4e0d\u9884\u8f7d\u5165","preload_metadata":"\u9884\u8f7d\u5165\u89c6\u9891Metadata","preload_auto":"\u8ba9\u7528\u6237\u6d4f\u89c8\u5668\u51b3\u5b9a",iframe:"Iframe",embeddedaudio:"\u5d4c\u5165\u58f0\u97f3"});