tinyMCE.addI18n('lb.style_dlg',{"text_lineheight":"Zeilenh\u00e9icht","text_variant":"Variant","text_style":"Stil","text_weight":"D\u00e9ckt","text_size":"Gr\u00e9isst","text_font":"Schr\u00ebftaart","text_props":"Text","positioning_tab":"Position\u00e9ierung","list_tab":"L\u00ebscht","border_tab":"Rumm","box_tab":"Box","block_tab":"Block","background_tab":"Hannergrond","text_tab":"Text",apply:"Iwwerhuelen",title:"CSS-Styles beaarbechten",clip:"Ausschn\u00ebtt",placement:"Plaz\u00e9ierung",overflow:"Verhale bei Iwwergr\u00e9isst",zindex:"Z-W\u00e4ert",visibility:"Siichtbar","positioning_type":"Aart vun der Position\u00e9ierung",position:"Position\u00e9ierung","bullet_image":"L\u00ebschtepunkt-Grafik","list_type":"L\u00ebschtepunkt-Aart",color:"Textfuerf",height:"H\u00e9icht",width:"Breet",style:"Format",margin:"Baussechten Ofstand",left:"L\u00e9nks",bottom:"\u00cbnnen",right:"Riets",top:"Uewen",same:"All selwecht",padding:"Banneschten Ofstand","box_clear":"\u00cbmfl\u00e9issung verh\u00ebnneren","box_float":"\u00cbmfl\u00e9issung","box_height":"H\u00e9icht","box_width":"Breet","block_display":"\u00cbmbrochverhalen","block_whitespace":"Automateschen \u00cbmbroch","block_text_indent":"Ar\u00e9ckung","block_text_align":"Ausriichtung","block_vertical_alignment":"Vertikal Ausriichtung","block_letterspacing":"Buschtawenofstand","block_wordspacing":"Wuertofstand","background_vpos":"Positioun Y","background_hpos":"Positioun X","background_attachment":"Waasserzeecheneffekt","background_repeat":"Widderhuelung","background_image":"Hannergrondbild","background_color":"Hannergrondfuerf","text_none":"keng","text_blink":"bl\u00ebnkend","text_case":"Schreiwung","text_striketrough":"duerchgestrach","text_underline":"\u00ebnnerstrach","text_overline":"iwwerstrach","text_decoration":"Gestaltung","text_color":"Fuerf",text:"Text",background:"Background",block:"Block",box:"Box",border:"Border",list:"List"});