tinyMCE.addI18n('dv.style_dlg',{"text_lineheight":"\u078a\u07ae\u0785\u07aa\u0788\u07a6\u078c\u07aa\u078e\u07ac \u078b\u07a8\u078e\u07aa\u0789\u07a8\u0782\u07b0","text_variant":"\u078c\u07a6\u078a\u07a7\u078c\u07aa\u0784\u07a7\u0788\u07a6\u078c\u07b0\u078c\u07a6\u0787\u07b0","text_style":"\u0790\u07b0\u0793\u07a6\u0787\u07a8\u078d\u07b0","text_weight":"Weight","text_size":"\u0790\u07a6\u0787\u07a8\u0792\u07b0","text_font":"\u078a\u07ae\u0782\u07b0\u0793\u07b0","text_props":"\u0787\u07a6\u0786\u07aa\u0783\u07aa","positioning_tab":"\u0795\u07ae\u0792\u07a8\u079d\u07a6\u0782\u07b0","list_tab":"\u078d\u07a8\u0790\u07b0\u0793\u07b0","border_tab":"\u0784\u07af\u0783\u0791\u07a6\u0783","box_tab":"\u078a\u07ae\u0781\u07a8","block_tab":"\u0784\u07aa\u078d\u07ae\u0786\u07b0","background_tab":"\u0784\u07ac\u0786\u07b0\u078e\u07aa\u0783\u07a6\u0787\u07aa\u0782\u07b0\u0791\u07b0","text_tab":"Text",apply:"Apply",title:"Edit CSS Style",clip:"Clip",placement:"Placement",overflow:"Overflow",zindex:"Z-index",visibility:"Visibility","positioning_type":"Type",position:"Position","bullet_image":"Bullet image","list_type":"Type",color:"Color",height:"Height",width:"Width",style:"Style",margin:"Margin",left:"Left",bottom:"Bottom",right:"Right",top:"Top",same:"Same for all",padding:"Padding","box_clear":"Clear","box_float":"Float","box_height":"Height","box_width":"Width","block_display":"Display","block_whitespace":"Whitespace","block_text_indent":"Text indent","block_text_align":"Text align","block_vertical_alignment":"Vertical alignment","block_letterspacing":"Letter spacing","block_wordspacing":"Word spacing","background_vpos":"Vertical position","background_hpos":"Horizontal position","background_attachment":"Attachment","background_repeat":"Repeat","background_image":"Background image","background_color":"Background color","text_none":"none","text_blink":"blink","text_case":"Case","text_striketrough":"strikethrough","text_underline":"underline","text_overline":"overline","text_decoration":"Decoration","text_color":"Color",text:"Text",background:"Background",block:"Block",box:"Box",border:"Border",list:"List"});