tinyMCE.addI18n('lb.xhtmlxtras_dlg',{"attribs_title":"Attributer af\u00fcgen/beaarbechten","option_rtl":"Riets no l\u00e9nks","option_ltr":"L\u00e9nks no riets","insert_date":"Aktuell Z\u00e4it/Datum af\u00fcgen",remove:"Ewechhuelen","title_cite_element":"Quellenangab","title_abbr_element":"Ofkierzung","title_acronym_element":"Akronym","title_del_element":"Ewechgehollenen Text","title_ins_element":"Agef\u00fcgtenen Text","fieldset_events_tab":"Ereegnes","fieldset_attrib_tab":"Attributer","fieldset_general_tab":"Allgemeng Astellungen","events_tab":"Ereegnes","attrib_tab":"Attributer","general_tab":"Allgemeng","attribute_attrib_tab":"Attributer","attribute_events_tab":"Ereegnes","attribute_label_accesskey":"Tastekierzel","attribute_label_tabindex":"Tabindex","attribute_label_langcode":"Sproochen","attribute_option_rtl":"Riets no l\u00e9nks","attribute_option_ltr":"L\u00e9nks no riets","attribute_label_langdir":"Schr\u00ebftrichtung","attribute_label_datetime":"Z\u00e4it/Datum","attribute_label_cite":"Quellenangab","attribute_label_style":"Format","attribute_label_class":"Klasse","attribute_label_id":"ID","attribute_label_title":"Titel"});