tinyMCE.addI18n('tw.advanced_dlg',{"link_list":"\u8d85\u9023\u7d50\u6e05\u55ae","link_is_external":"\u60a8\u8f38\u5165\u7684 URL \u662f\u4e00\u500b\u5916\u90e8\u8d85\u9023\u7d50\uff0c\u662f\u5426\u8981\u52a0\u4e0a http:// \uff1f","link_is_email":"\u60a8\u8f38\u5165\u7684\u662f\u96fb\u5b50\u90f5\u4ef6\u5730\u5740,\u662f\u5426\u9700\u8981\u52a0 mailto:\uff1f","link_titlefield":"\u6a19\u984c","link_target_blank":"\u65b0\u8996\u7a97\u6253\u958b\u8d85\u9023\u7d50","link_target_same":"\u76ee\u524d\u8996\u7a97\u6253\u958b\u8d85\u9023\u7d50","link_target":"\u76ee\u6a19","link_url":"\u8d85\u9023\u7d50URL","link_title":"\u63d2\u5165/\u7de8\u8f2f\u8d85\u9023\u7d50","image_align_right":"\u9760\u53f3","image_align_left":"\u9760\u5de6","image_align_textbottom":"\u6587\u5b57\u4e0b\u65b9","image_align_texttop":"\u6587\u5b57\u4e0a\u65b9","image_align_bottom":"\u9760\u4e0b","image_align_middle":"\u7f6e\u4e2d","image_align_top":"\u9760\u4e0a","image_align_baseline":"\u57fa\u6e96\u7dda","image_align":"\u5c0d\u9f4a\u65b9\u5f0f","image_hspace":"\u6c34\u5e73\u9593\u8ddd","image_vspace":"\u5782\u76f4\u9593\u8ddd","image_dimensions":"\u5c3a\u5bf8","image_alt":"\u5716\u7247\u8aaa\u660e","image_list":"\u5716\u7247\u6e05\u55ae","image_border":"\u908a\u6846","image_src":"\u5716\u7247URL","image_title":"\u63d2\u5165/\u7de8\u8f2f\u5716\u7247","charmap_title":"\u63d2\u5165\u7279\u6b8a\u7b26\u865f","colorpicker_name":"\u540d\u7a31\uff1a","colorpicker_color":"\u984f\u8272\uff1a","colorpicker_named_title":"\u5e38\u7528\u984f\u8272","colorpicker_named_tab":"\u5e38\u7528\u984f\u8272","colorpicker_palette_title":"WEB\u984f\u8272","colorpicker_palette_tab":"\u5b89\u5168\u8272","colorpicker_picker_title":"\u8abf\u8272\u76e4","colorpicker_picker_tab":"\u8abf\u8272\u76e4","colorpicker_title":"\u9078\u64c7\u984f\u8272","code_wordwrap":"\u81ea\u52d5\u63db\u884c","code_title":"\u539f\u59cb\u78bc\u6a19\u984c","anchor_name":"\u66f8\u7c64\u540d\u7a31","anchor_title":"\u63d2\u5165/\u7de8\u8f2f\u66f8\u7c64","about_loaded":"\u5df2\u555f\u7528\u7684\u5916\u639b\u7a0b\u5f0f","about_version":"\u7248\u672c","about_author":"\u4f5c\u8005","about_plugin":"\u5916\u639b\u7a0b\u5f0f","about_plugins":"\u5916\u639b\u7a0b\u5f0f","about_license":"\u6388\u6b0a","about_help":"\u8aaa\u660e","about_general":"\u95dc\u65bc","about_title":"\u95dc\u65bc TinyMCE","anchor_invalid":"Please specify a valid anchor name.","accessibility_help":"Accessibility Help","accessibility_usage_title":"General Usage"});